------------------------------------------------------------------------------------------------------------------------
-- CONFIGURATION
------------------------------------------------------------------------------------------------------------------------

-- READ CALENDAR
select
	*
from
	cfe.CALENDAR
;

-- READ CALENDAR HOLIDAY
select
	*
from
	cfe.CALENDAR_HOLIDAY
where
	ID_CALENDAR = ?
;

-- READ CURRENCY
select
	*
from
	cfe.CURRENCY
;

-- READ FX RATE
select
	*
from
	cfe.FXRATE
;

-- READ RATE HIST
select
	*
from
	cfe.RATE_HIST
;

-- READ RATE CURVE DATES
select distinct id_rate, valid_date from cfe.rate_curve;

-- READ RATE CURVE
select * from cfe.rate_curve
where id_rate=? and valid_date=?;


-- READ RATE CURVES DEFINITION
select * from cfe.rate_curve_definition;


-- READ SCRIPT
select
	*
from
	cfe.SCRIPT
;

-- READ FEETYPE
select
	*
from
	cfe.FEE_TYPE
;

-- READ ACCOUNTING SCOPE
select
	*
from cfe.ACCOUNTING_SCOPE
;

-- READ ACCOUNTING EVENTS
select
	*
from cfe.ACCOUNTING_EVENT
where ID_ACCOUNTING_SCOPE = ?
;

-- READ LEDGER ACCOUNTS
select
	*
from cfe.LEDGER_ACCOUNT
;


------------------------------------------------------------------------------------------------------------------------
-- DATA
------------------------------------------------------------------------------------------------------------------------

-- GET INSTRUMENT LIST
select
	id_instrument
from
	cfe.INSTRUMENT
order by
	id_instrument
;

-- READ INSTRUMENT
select
	*
from
	cfe.INSTRUMENT where id_instrument = ?
;

-- READ INTEREST PERIOD
select
	*
from
	cfe.INTEREST_PERIOD where ID_INSTRUMENT = ?
;

-- READ SCHEDULE
select
	*
from
	cfe.SCHEDULE where ID_INSTRUMENT = ?
;

-- READ ONE TIME PAYMENT
select
	*
from
	cfe.ONE_TIME_PAYMENT
where
	ID_INSTRUMENT = ?
;

-- READ RECONCILIATION NOMINAL
select
	*
from
	cfe.RECONCILIATION_NOMINAL
where
	ID_INSTRUMENT = ?
;

-- READ INSTRUMENT ATTRIBUTES
select
	*
from
	cfe.INSTRUMENT_ATTRIBUTE
where
	ID_INSTRUMENT = ?
;

-- READ INSTRUMENT TRANSACTIONS
select
	*
from
	cfe.TRANSACTION
where
	ID_INSTRUMENT = ?
;

-- READ INSTRUMENT PRICES
select
	*
from
	cfe.INSTRUMENT_PRICE
where
	ID_INSTRUMENT = ?
ORDER BY
	valid_timestamp ASC
;

------------------------------------------------------------------------------------------------------------------------
-- MEASURES
------------------------------------------------------------------------------------------------------------------------

-- READ BALANCE MEASURES BY VALUEDATE
select
	*
from
	cfe.INSTRUMENT_MEASURE_BALANCE t1
where
	ID_INSTRUMENT= ?
	and REPORT_DATE = (select max(REPORT_DATE)
                            from cfe.INSTRUMENT_MEASURE_BALANCE
					where ID_INSTRUMENT=t1.ID_INSTRUMENT
						and REPORT_DATE < ?)
        and VERSION = (select max(VERSION)
					from cfe.INSTRUMENT_MEASURE_BALANCE
					where ID_INSTRUMENT=t1.ID_INSTRUMENT
						and REPORT_DATE=t1.REPORT_DATE)
;

-- READ POSITION MEASURES BY VALUEDATE
select
	*
from
	cfe.POSITION_MEASURE t1
where
	ID_INSTRUMENT= ?
	and REPORT_DATE = (select max(REPORT_DATE)
                            from cfe.POSITION_MEASURE
					where ID_INSTRUMENT=t1.ID_INSTRUMENT
						and REPORT_DATE < ?)
        and VERSION = (select max(VERSION)
					from cfe.POSITION_MEASURE
					where ID_INSTRUMENT=t1.ID_INSTRUMENT
						and REPORT_DATE=t1.REPORT_DATE)
;

-- READ INCOME MEASURES BY VALUEDATE
select
	*
from
	cfe.INSTRUMENT_MEASURE_INCOME t1
where
	ID_INSTRUMENT= ?
	and REPORT_DATE = (select max(REPORT_DATE)
                            from cfe.INSTRUMENT_MEASURE_INCOME
					where ID_INSTRUMENT=t1.ID_INSTRUMENT
						and REPORT_DATE < ?)
        and VERSION = (select max(VERSION)
					from cfe.INSTRUMENT_MEASURE_INCOME
					where ID_INSTRUMENT=t1.ID_INSTRUMENT
						and REPORT_DATE=t1.REPORT_DATE)
;

-- READ FEE MEASURES BY VALUEDATE
select
	*
from
	cfe.INSTRUMENT_MEASURE_FEE t1
where
	ID_INSTRUMENT= ?
	and REPORT_DATE = (select max(REPORT_DATE)
                            from cfe.INSTRUMENT_MEASURE_FEE
					where ID_INSTRUMENT=t1.ID_INSTRUMENT
						and REPORT_DATE < ?)
        and VERSION = (select max(VERSION)
					from cfe.INSTRUMENT_MEASURE_FEE
					where ID_INSTRUMENT=t1.ID_INSTRUMENT
						and REPORT_DATE=t1.REPORT_DATE)
;

-- READ INCOME MEASURES BY VALUEDATE
select
	*
from
	cfe.INSTRUMENT_MEASURE_INCOME t1
where
	ID_INSTRUMENT= ?
	and REPORT_DATE = ?
	and VERSION = (select max(VERSION)
					from cfe.INSTRUMENT_MEASURE_INCOME
					where ID_INSTRUMENT=t1.ID_INSTRUMENT
						and REPORT_DATE=t1.REPORT_DATE)
;

-- READ IMPAIRMENT MEASURES BY VALUEDATE
select
	*
from
	cfe.INSTRUMENT_MEASURE_IMPAIRMENT t1
where
	ID_INSTRUMENT= ?
	and REPORT_DATE = ?
	and VERSION = (select max(VERSION)
					from cfe.INSTRUMENT_MEASURE_IMPAIRMENT
					where ID_INSTRUMENT=t1.ID_INSTRUMENT
						and REPORT_DATE=t1.REPORT_DATE)
;

-- READ FEE MEASURES BY VALUEDATE
select
	*
from
	cfe.INSTRUMENT_MEASURE_FEE t1
where
	ID_INSTRUMENT= ?
	and REPORT_DATE = ?
	and VERSION = (select max(VERSION)
					from cfe.INSTRUMENT_MEASURE_FEE
					where ID_INSTRUMENT=t1.ID_INSTRUMENT
						and REPORT_DATE=t1.REPORT_DATE)
;

-- READ ACCOUNTS BY INSTRUMENT ID
select distinct
	t1.*
from
	cfe.LEDGER_ACCOUNT t1
	inner join cfe.LEDGER_ACCOUNT_ENTRY t2 on t1.ID_ACCOUNT=t2.ID_ACCOUNT_CREDIT
where t2.ID_INSTRUMENT = ?
union select distinct
	t1.*
from
	cfe.LEDGER_ACCOUNT t1
	inner join cfe.LEDGER_ACCOUNT_ENTRY t2 on t1.ID_ACCOUNT=t2.ID_ACCOUNT_DEBIT
where t2.ID_INSTRUMENT = ?
order by
	code
	, id_fee_type
	, id_currency
;

-- READ ACCOUNTING ENTRIES BY INSTRUMENT ID
select
	*
from
	cfe.LEDGER_ACCOUNT_ENTRY
where
	ID_INSTRUMENT = ?
order by
    value_date
    , posting_date
;

-- READ POSTING DATES BY INSTRUMENT ID
select distinct
	t1.REPORT_DATE
	, t1.VERSION
from
	cfe.INSTRUMENT_MEASURE_BALANCE t1
where
	ID_INSTRUMENT = ?
and
	t1.version = (select max(version) from cfe.INSTRUMENT_MEASURE_BALANCE where ID_INSTRUMENT=? and REPORT_DATE=t1.REPORT_DATE)
order by
    t1.REPORT_DATE
	, t1.VERSION
;

-- READ BALANCES BY GL
select
	code            "GL Code"
	, description   "Description"
	, sum(amount)   "Amount"
	, id_currency   "Curr."
	, id_fee_type   "FT"
from
(
	select
		code
		, description
		, amount
		, id_currency
		, id_fee_type
	from
		cfe.LEDGER_ACCOUNT a
		inner join cfe.LEDGER_ACCOUNT_ENTRY b on a.ID_ACCOUNT=b.ID_ACCOUNT_CREDIT
	where
		code like ?
	union all select
		code
		, description
		, -amount
		, id_currency
		, id_fee_type
	from
		cfe.LEDGER_ACCOUNT a
		inner join cfe.LEDGER_ACCOUNT_ENTRY b on a.ID_ACCOUNT=b.ID_ACCOUNT_DEBIT
	where
		code like ?
)
group by
	code
	, description
	, id_currency
	, id_fee_type
UNION ALL
select
	''				"GL Code"
	, 'Total'		"Description"
	, sum(amount)   "Amount"
	, ''			"Curr."
	, ''			"FT"
from
(
	select
		code
		, description
		, amount
		, id_currency
		, id_fee_type
	from
		cfe.LEDGER_ACCOUNT a
		inner join cfe.LEDGER_ACCOUNT_ENTRY b on a.ID_ACCOUNT=b.ID_ACCOUNT_CREDIT
	where
		code like ?
	union all select
		code
		, description
		, -amount
		, id_currency
		, id_fee_type
	from
		cfe.LEDGER_ACCOUNT a
		inner join cfe.LEDGER_ACCOUNT_ENTRY b on a.ID_ACCOUNT=b.ID_ACCOUNT_DEBIT
	where
		code like ?
)
order by 1
;

-- READ POSTINGS BY GL
select
	value_date                                  "Value Date"
	, posting_date                              "Posting Date"
	, id_instrument                             "Instrument ID"
        , b.DESCRIPTION                             "Description"
	, case
            when CODE_DEBIT_ACCOUNT = ? then 'D'
            when CODE_CREDIT_ACCOUNT = ? then 'C'
          end                                       "D/C"
	, amount                                    "Amount"
	, amount_bc                                 "Amount BC"
from
	cfe.LEDGER_ACCOUNT_ENTRY a
	inner join cfe.ACCOUNTING_EVENT b on a.ID_ACCOUNTING_EVENT=b.ID_ACCOUNTING_EVENT
where
	(CODE_DEBIT_ACCOUNT = ?
		or CODE_CREDIT_ACCOUNT = ? )
order by
	1,2,3
;

-- READ BALANCE MEASURES BY INSTRUMENT ID AND VALUE DATE
select
	*
from
	cfe.INSTRUMENT_MEASURE_BALANCE t1
where
	ID_INSTRUMENT = ?
	and REPORT_DATE = ?
	and VERSION =?
;

-- READ INCOME MEASURES BY INSTRUMENT ID AND VALUE DATE
select
	*
from
	cfe.INSTRUMENT_MEASURE_INCOME t1
where
	ID_INSTRUMENT = ?
	and REPORT_DATE = ?
	and VERSION =?
;

-- READ FEE MEASURES BY INSTRUMENT ID AND VALUE DATE
select
	*
from
	cfe.INSTRUMENT_MEASURE_FEE t1
where
	ID_INSTRUMENT = ?
	and REPORT_DATE = ?
	and VERSION =?
;

-- READ IMPAIRMENT MEASURES BY INSTRUMENT ID AND VALUE DATE
select
	*
from
	cfe.INSTRUMENT_MEASURE_IMPAIRMENT t1
where
	ID_INSTRUMENT = ?
	and REPORT_DATE = ?
	and VERSION =?
;

-- READ POSITION MEASURES BY INSTRUMENT ID AND VALUE DATE
select
	*
from
	cfe.POSITION_MEASURE t1
where
	ID_INSTRUMENT = ?
	and REPORT_DATE = ?
	and VERSION =?
;

------------------------------------------------------------------------------------------------------------------------
-- MEASURES
------------------------------------------------------------------------------------------------------------------------

-- GET USED ATTRIBUTES
select
	*
from
	cfe.ATTRIBUTE t1
where
	exists (select 1 from cfe.INSTRUMENT_ATTRIBUTE where ID_ATTRIBUTE=t1.ID_ATTRIBUTE)
;

-- GET BALANCE MEASURES BY ATTRIBUTE
select
	t2.ATTRIBUTE_VALUE				"Dimension"
	, t1.ASSET_LIABILITY_FLAG		"A/L"
	, sum(t1.NOMINAL_BALANCE_BC)		"Nominal"
	, sum(t1.ACCRUED_INTEREST_BC)		"Accr. Interest"
	, sum(t1.AMORTISED_COST_DIRTY_BC)		"Amort. Cost"
	, avg(t1.YIELD)				"Yield [%]"
from
	cfe.INSTRUMENT_MEASURE_BALANCE t1
	inner join cfe.INSTRUMENT_ATTRIBUTE t2 on t1.ID_INSTRUMENT=t2.ID_INSTRUMENT
where
	id_attribute = ?
	and REPORT_DATE = (select max(REPORT_DATE)
                            from cfe.INSTRUMENT_MEASURE_BALANCE)
    and VERSION = (select max(VERSION)
					from cfe.INSTRUMENT_MEASURE_BALANCE
					where REPORT_DATE=t1.REPORT_DATE)
group by
	t2.ATTRIBUTE_VALUE
	, t1.ASSET_LIABILITY_FLAG
;