/*
 *
 *  Copyright (C) 2012 Andreas Reichel <andreas@manticore-projects.com>
 *
 * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or (at
 *  your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful, but
 *  WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 *  General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License along
 *  with this program; if not, write to the Free Software Foundation, Inc.,
 *  59 Temple Place, Suite 330, Boston, MA 02111-1307 USA.
 *
 * ~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~
 */
/*
select 'drop table "' || table_name || '";' from user_tables
union all select 'drop view "' || view_name || '";' from user_views
union all select 'drop sequence "' || sequence_name || '";' from user_sequences;

drop table "VERSION_INFO";
drop table "CURRENCY";
drop table "FXRATE";
drop table "INTEREST_RATE_CURVE";
drop table "SCRIPT";
drop table "FEE_TYPE";
drop table "SYS_INSTRUMENT_TYPE";
drop table "SYS_CASHFLOW_TYPE";
drop table "SYS_BUSINESS_DAY_CONVENTION";
drop table "SYS_PAYMENT_CONVENTION";
drop table "SYS_DAY_COUNT_CONVENTION";
drop table "SYS_DAY_INCL_CONVENTION";
drop table "CALENDAR";
drop table "CALENDAR_HOLIDAY";
drop table "INSTRUMENT";
drop table "INTEREST_PERIOD";
drop table "SCHEDULE";
drop table "ONE_TIME_PAYMENT";
drop table "RECONCILIATION_NOMINAL";
drop table "INSTRUMENT_IMPORT_MEASURE";
drop table "POSITION";
drop table "POSITION_TRANSACTION";
drop table "EXECUTION";
drop table "INSTRUMENT_MEASURE";
drop table "INSTRUMENT_MEASURE_FEE";
drop table "LEDGER_ACCOUNT";
drop table "LEDGER_ACCOUNT_BALANCE";
drop table "LEDGER_POSTINGS";



create user cfe identified by cfe;
grant create session to cfe;
grant create table to cfe;
grant create view to cfe;
grant create sequence to cfe;
grant unlimited tablespace to cfe;
commit;
*/
/*
drop schema cfe;
*/

CREATE SCHEMA cfe;
CREATE TABLE cfe.version_info
  (
     major_version        SMALLINT NOT NULL
     , minor_version      SMALLINT NOT NULL
     , patch_level        SMALLINT NOT NULL
     , installation_start TIMESTAMP
     , installation_end   TIMESTAMP
  );

CREATE UNIQUE INDEX cfe.version_info_idx1
  ON cfe.version_info (major_version, minor_version, patch_level);

INSERT INTO cfe.version_info
VALUES      (0
             , 0
             , 5
             , SYSDATE
             , NULL);

---------------------------------------------------------------------------------------------------------------
-- CONFIGURATION FOR CUSTOMIZATION
CREATE TABLE cfe.calendar
  (
     id_calendar           VARCHAR(12) PRIMARY KEY NOT NULL
     , year_offset         SMALLINT NOT NULL
     , friday_is_holiday   VARCHAR(1) NOT NULL
     , saturday_is_holiday VARCHAR(1) NOT NULL
     , sunday_is_holiday   VARCHAR(1) NOT NULL
  );

CREATE TABLE cfe.calendar_holiday
  (
     id_calendar VARCHAR(12) NOT NULL
     , holiday   DATE NOT NULL
  );

CREATE UNIQUE INDEX cfe.calendar_holiday_idx1
  ON cfe.calendar_holiday(id_calendar, holiday);

CREATE TABLE cfe.currency
  (
     id_currency   VARCHAR(3) PRIMARY KEY NOT NULL
     , description VARCHAR(255)
  );

INSERT INTO cfe.currency
VALUES      ('EUR'
             , 'EURO');

INSERT INTO cfe.currency
VALUES      ('USD'
             , 'United States Dollar');

INSERT INTO cfe.currency
VALUES      ('JPY'
             , 'Japanese Yen');

INSERT INTO cfe.currency
VALUES      ('GBP'
             , 'Great British Pound');

INSERT INTO cfe.currency
VALUES      ('CHF'
             , 'Swiss Franken');

INSERT INTO cfe.currency
VALUES      ('NGN'
             , 'Nigerian Naira');

CREATE TABLE cfe.fxrate
  (
     id_currency_from   VARCHAR(3) NOT NULL
     , id_currency_into VARCHAR(3) NOT NULL
     , value_date       DATE NOT NULL
     , fxrate           DECIMAL(15, 9) NOT NULL
  );

CREATE UNIQUE INDEX cfe.fxfrate_idx1
  ON cfe.fxrate(id_currency_from, id_currency_into, value_date);

CREATE TABLE cfe.rate_hist
  (
     id_rate      VARCHAR(12) PRIMARY KEY NOT NULL
     , value_date DATE NOT NULL
     , rate       DECIMAL(15, 9) NOT NULL
  );
CREATE UNIQUE INDEX cfe.rate_hist_idx1
  ON cfe.rate_hist (id_rate, value_date);

--drop table cfe.rate_curve cascade;
CREATE TABLE cfe.rate_curve_definition (
	id_rate						    VARCHAR(12) NOT NULL
    , valid_date					DATE NOT NULL
	, id_instrument					VARCHAR(40) NOT NULL
	, maturity_date					DATE NOT NULL
	, id_business_day_convention	VARCHAR(12)
	, id_day_count_convention		VARCHAR(12)
	, period_scalar					SMALLINT
    , id_period_type				VARCHAR(1)
	, previous_drop_date			DATE
	, coupon_rate					DECIMAL(12, 9)
	, price							DECIMAL(23, 9) NOT NULL
	, id_price_type					VARCHAR(1) NOT NULL
);
CREATE UNIQUE INDEX cfe.rate_curve_definition_idx1
on cfe.rate_curve_definition (id_rate, valid_date, id_instrument);
CREATE UNIQUE INDEX cfe.rate_curve_definition_idx2
on cfe.rate_curve_definition (id_rate, valid_date, maturity_date);

CREATE TABLE cfe.rate_curve
  (
     id_rate         VARCHAR(12) NOT NULL
     , valid_date     DATE NOT NULL
     , period_scalar  SMALLINT
     , id_period_type VARCHAR(1)
     , rate           DECIMAL(15, 9) NOT NULL
  );

CREATE UNIQUE INDEX cfe.rate_curve_idx1
  ON cfe.rate_curve (id_rate, valid_date, period_scalar, id_period_type);

CREATE TABLE cfe.script
  (
     id_script     VARCHAR(12) PRIMARY KEY NOT NULL
     , id_language VARCHAR(12) NOT NULL
     , content     CLOB NOT NULL
  );

CREATE TABLE cfe.fee_type
  (
     id_fee_type   VARCHAR(12) PRIMARY KEY NOT NULL
     , description VARCHAR(255)
  );

CREATE TABLE cfe.attribute
  (
     id_attribute  VARCHAR(40) PRIMARY KEY NOT NULL
     , label       VARCHAR(40)	-- label shown in the GUI
     , description CLOB			-- descriptio shown in the GUI
     , value_type  VARCHAR(1)	-- "I"nteger, "D"ate, "N"umber, "T"ext
     , mandatory   VARCHAR(1)	-- true/false
     , reference   VARCHAR(255)	-- qualified reference like schema.table_name.field_name
  );

INSERT INTO cfe.attribute
VALUES (
	'segment'
	, 'Bangking Segment'
	, null
	, 'T'
	, 0
	, null
);

INSERT INTO cfe.attribute
VALUES (
	'product'
	, 'Product Code'
	, null
	, 'T'
	, 0
	, null
);

INSERT INTO cfe.attribute
VALUES (
	'branch'
	, 'Branch Code'
	, null
	, 'T'
	, 0
	, null
);

CREATE TABLE cfe.portfolio_coll_impairment
  (
     id_portfolio VARCHAR(40) PRIMARY KEY NOT NULL
     , rate_pd    VARCHAR(12)
     , rate_lgd   VARCHAR(12)
  );

---------------------------------------------------------------------------------------------------------------
-- SYSTEM DICTIONARY FOR REFERENCE ONLY
CREATE TABLE cfe.sys_instrument_type
  (
     id_instrument_type VARCHAR(12) PRIMARY KEY NOT NULL
     , description      CLOB
  );

INSERT INTO cfe.sys_instrument_type
VALUES      ('loan'
             , 'Loans granted to to consumers, corporates or souvereigns');

INSERT INTO cfe.sys_instrument_type
VALUES      ('deposit'
             , 'Fixed Term Deposits of customers, corporates or souvereigns');

INSERT INTO cfe.sys_instrument_type
VALUES      ('creditline'
             , 'Line of Credit granted to to consumers, corporates or souvereigns');

INSERT INTO cfe.sys_instrument_type
VALUES      ('guarantee'
             , 'Financial Guarantees granted to to consumers, corporates or souvereigns');

INSERT INTO cfe.sys_instrument_type
VALUES      ('curr_acc'
             , 'Current Accounts of consumers, corporates or souvereigns');

INSERT INTO cfe.sys_instrument_type
VALUES      ('sec_htm'
             , 'Purchased Securities held to maturity or available for sale');

INSERT INTO cfe.sys_instrument_type
VALUES      ('sec_hft'
             , 'Purchased Securities held for trading');

INSERT INTO cfe.sys_instrument_type
VALUES      ('sec_afs'
             , 'Purchased Securities available for sale');

INSERT INTO cfe.sys_instrument_type
VALUES      ('debenture'
             , 'Issued debentures');

INSERT INTO cfe.sys_instrument_type
VALUES      ('fxdeal'
             , 'Foreign currency deals');

INSERT INTO cfe.sys_instrument_type
VALUES      ('collateral'
             , 'Received collaterals off-balance.');

INSERT INTO cfe.sys_instrument_type
VALUES      ('insurance'
             , 'Issued insurance contract according to the IFRS 4.');

CREATE TABLE cfe.sys_cashflow_type
  (
     id_cashflow_type VARCHAR(1) PRIMARY KEY NOT NULL
     , description    CLOB
  );

INSERT INTO cfe.sys_cashflow_type
VALUES      ('C'
             , 'Granting commitment');

INSERT INTO cfe.sys_cashflow_type
VALUES      ('c'
             , 'Expired commitment');

INSERT INTO cfe.sys_cashflow_type
VALUES      ('D'
             , 'Disbursement or Deposit');

INSERT INTO cfe.sys_cashflow_type
VALUES      ('R'
             , 'Repayment, expteced');

INSERT INTO cfe.sys_cashflow_type
VALUES      ('A'
             , 'Loan repayment including interest, expteced');

INSERT INTO cfe.sys_cashflow_type
VALUES      ('U'
             , 'Loan repayment, unexpected');

INSERT INTO cfe.sys_cashflow_type
VALUES      ('G'
             , 'Granting guarantee');

INSERT INTO cfe.sys_cashflow_type
VALUES      ('g'
             , 'Expired guarantee');

INSERT INTO cfe.sys_cashflow_type
VALUES      ('I'
             , 'Paid interest');

INSERT INTO cfe.sys_cashflow_type
VALUES      ('F'
             , 'Fee to be amortized with EIR');

INSERT INTO cfe.sys_cashflow_type
VALUES      ('f'
             , 'Fee to be amortized straight line');

INSERT INTO cfe.sys_cashflow_type
VALUES      ('0'
             , 'Fee to be posted directly into profit/loss');

INSERT INTO cfe.sys_cashflow_type
VALUES      ('y'
             , 'Penalty interest');

CREATE TABLE cfe.sys_period_type
  (
     id_period_type VARCHAR(1) PRIMARY KEY NOT NULL
     , description  CLOB
  );

INSERT INTO cfe.sys_period_type
VALUES      ('D'
             , 'Daily');

INSERT INTO cfe.sys_period_type
VALUES      ('W'
             , 'Weekly');

INSERT INTO cfe.sys_period_type
VALUES      ('M'
             , 'Monthly');

INSERT INTO cfe.sys_period_type
VALUES      ('Q'
             , 'Quarterly');

INSERT INTO cfe.sys_period_type
VALUES      ('T'
             , 'Tri-Annual');

INSERT INTO cfe.sys_period_type
VALUES      ('S'
             , 'Semi-Annual');

INSERT INTO cfe.sys_period_type
VALUES      ('Y'
             , 'Annual');

CREATE TABLE cfe.sys_business_day_convention
  (
     id_business_day_convention VARCHAR(12) PRIMARY KEY NOT NULL
     , description              CLOB
  );

INSERT INTO cfe.sys_business_day_convention
VALUES      ('I'
             , 'IGNORE holidays and settle on every day');

INSERT INTO cfe.sys_business_day_convention
VALUES      ('P'
             , 'Settle on PREVIOUS businessday but keep value day');

INSERT INTO cfe.sys_business_day_convention
VALUES      ('PS'
             , 'Settle on PREVIOUS businessday and SHIFT value day accordingly');

INSERT INTO cfe.sys_business_day_convention
VALUES      ('PF'
             , 'Settle on FIRST or PREVIOUS businessday of the month but keep value day');

INSERT INTO cfe.sys_business_day_convention
VALUES      ('PFS'
             , 'Settle on FIRST or PREVIOUS businessday of the month and SHIFT value day accordingly' );

INSERT INTO cfe.sys_business_day_convention
VALUES      ('N'
             , 'Settle on NEXT businessday but keep value day');

INSERT INTO cfe.sys_business_day_convention
VALUES      ('NS'
             , 'Settle on NEXT businessday and SHIFT value day accordingly');

INSERT INTO cfe.sys_business_day_convention
VALUES      ('NL'
             , 'Settle on LAST or NEXT businessday but keep value day');

INSERT INTO cfe.sys_business_day_convention
VALUES      ('NLS'
             , 'Settle on LAST or NEXT businessday and SHIFT value day accordingly');

CREATE TABLE cfe.sys_payment_convention
  (
     id_payment_convention VARCHAR(12) PRIMARY KEY NOT NULL
     , description         CLOB
  );

INSERT INTO cfe.sys_payment_convention
VALUES      ('ADVANCE'
             , 'Payment in ADVANCE at the beginning of the period');

INSERT INTO cfe.sys_payment_convention
VALUES      ('ARREARS'
             , 'Payment in ARREARS at the end of the period');

INSERT INTO cfe.sys_payment_convention
VALUES      ('COMPOUND'
             , 'COMPOUNDING at the end of the period');

CREATE TABLE cfe.sys_day_count_convention
  (
     id_day_count_convention VARCHAR(12) PRIMARY KEY NOT NULL
     , description           CLOB
  );

INSERT INTO cfe.sys_day_count_convention
VALUES      ('act/act'
             , 'ACT/ACT');

INSERT INTO cfe.sys_day_count_convention
VALUES      ('act/360'
             , 'ACT/360');

INSERT INTO cfe.sys_day_count_convention
VALUES      ('act/365'
             , 'ACT/365');

INSERT INTO cfe.sys_day_count_convention
VALUES      ('act/366'
             , 'ACT/366');

INSERT INTO cfe.sys_day_count_convention
VALUES      ('30/360'
             , '30/360');

INSERT INTO cfe.sys_day_count_convention
VALUES      ('30e/360'
             , '30e/360 February counts 28 days');

CREATE TABLE cfe.sys_day_incl_convention
  (
     id_day_incl_convention VARCHAR(12) PRIMARY KEY NOT NULL
     , description          CLOB
  );

INSERT INTO cfe.sys_day_incl_convention
VALUES      ('InclExcl'
             , 'INCLUDE the first day and EXCLUDE the last day');

CREATE TABLE cfe.sys_fixingmode
  (
     id_fixingmode SMALLINT PRIMARY KEY NOT NULL
     , descript    CLOB
  );

INSERT INTO cfe.sys_fixingmode
VALUES      (0
             , 'DAILY, fixing values on the day of the base rate change');

INSERT INTO cfe.sys_fixingmode
VALUES      (1
             , 'PAYMENT, fixing applies on the day of the next interest payment');

CREATE TABLE cfe.sys_measure (
	id_measure SMALLINT PRIMARY KEY NOT NULL
	, measure  VARCHAR(255) NOT NULL
	, description clob
);
create unique index cfe.sys_measure_idx1
on cfe.sys_measure(measure);

delete from cfe.sys_measure;
INSERT INTO cfe.sys_measure VALUES (1, 'ACCRUED_INTEREST', '');
INSERT INTO cfe.sys_measure VALUES (2, 'ACCRUED_INTEREST_D', '');
INSERT INTO cfe.sys_measure VALUES (3, 'ACCRUED_INTEREST_DD', '');
INSERT INTO cfe.sys_measure VALUES (4, 'ACCRUED_INTEREST_P', '');
INSERT INTO cfe.sys_measure VALUES (5, 'ACCRUED_INTEREST_PP', '');
INSERT INTO cfe.sys_measure VALUES (7, 'FEE', '');
INSERT INTO cfe.sys_measure VALUES (8, 'FEE_D', '');
INSERT INTO cfe.sys_measure VALUES (9, 'FEE_DD', '');
INSERT INTO cfe.sys_measure VALUES (10, 'FEE_DIRECT_PL_D', '');
INSERT INTO cfe.sys_measure VALUES (11, 'FEE_DIRECT_PL_DD', '');
INSERT INTO cfe.sys_measure VALUES (12, 'FEE_PP', '');
INSERT INTO cfe.sys_measure VALUES (13, 'FEE_SL', '');
INSERT INTO cfe.sys_measure VALUES (14, 'FEE_SL_D', '');
INSERT INTO cfe.sys_measure VALUES (15, 'FEE_SL_DD', '');
INSERT INTO cfe.sys_measure VALUES (16, 'FEE_SL_PP', '');
INSERT INTO cfe.sys_measure VALUES (17, 'IMPAIRMENT', '');
INSERT INTO cfe.sys_measure VALUES (18, 'IMPAIRMENT_P', '');
INSERT INTO cfe.sys_measure VALUES (19, 'INTEREST_D', '');
INSERT INTO cfe.sys_measure VALUES (20, 'INTEREST_DD', '');
INSERT INTO cfe.sys_measure VALUES (21, 'INTEREST_SMOOTHING', '');
INSERT INTO cfe.sys_measure VALUES (22, 'INTEREST_SMOOTHING_D', '');
INSERT INTO cfe.sys_measure VALUES (23, 'INTEREST_SMOOTHING_DD', '');
INSERT INTO cfe.sys_measure VALUES (24, 'INTEREST_SMOOTHING_P', '');
INSERT INTO cfe.sys_measure VALUES (25, 'INTEREST_SMOOTHING_PP', '');
INSERT INTO cfe.sys_measure VALUES (26, 'NOMINAL_BALANCE', '');
INSERT INTO cfe.sys_measure VALUES (27, 'NOMINAL_BALANCE_P', '');
INSERT INTO cfe.sys_measure VALUES (28, 'NOMINAL_BALANCE_PP', '');
INSERT INTO cfe.sys_measure VALUES (29, 'NOMINAL_D', '');
INSERT INTO cfe.sys_measure VALUES (30, 'NOMINAL_DD', '');
INSERT INTO cfe.sys_measure VALUES (31, 'PENALTY_INTEREST_D', '');
INSERT INTO cfe.sys_measure VALUES (32, 'PENALTY_INTEREST_DD', '');
INSERT INTO cfe.sys_measure VALUES (33, 'RECOVERY_BALANCE', '');
INSERT INTO cfe.sys_measure VALUES (34, 'RECOVERY_BALANCE_P', '');
INSERT INTO cfe.sys_measure VALUES (35, 'RECOVERY_BALANCE_PP', '');
INSERT INTO cfe.sys_measure VALUES (36, 'RECOVERY_D', '');
INSERT INTO cfe.sys_measure VALUES (37, 'RECOVERY_DD', '');
INSERT INTO cfe.sys_measure VALUES (38, 'UNAMORTIZED_FEE', '');
INSERT INTO cfe.sys_measure VALUES (39, 'UNAMORTIZED_FEE_D', '');
INSERT INTO cfe.sys_measure VALUES (40, 'UNAMORTIZED_FEE_DD', '');
INSERT INTO cfe.sys_measure VALUES (41, 'UNAMORTIZED_FEE_P', '');
INSERT INTO cfe.sys_measure VALUES (42, 'UNAMORTIZED_FEE_PP', '');
INSERT INTO cfe.sys_measure VALUES (43, 'UNAMORTIZED_FEE_SL', '');
INSERT INTO cfe.sys_measure VALUES (44, 'UNAMORTIZED_FEE_SL_D', '');
INSERT INTO cfe.sys_measure VALUES (45, 'UNAMORTIZED_FEE_SL_DD', '');
INSERT INTO cfe.sys_measure VALUES (46, 'UNAMORTIZED_FEE_SL_P', '');
INSERT INTO cfe.sys_measure VALUES (47, 'UNAMORTIZED_FEE_SL_PP', '');
INSERT INTO cfe.sys_measure VALUES (48, 'UNWINDING', '');
INSERT INTO cfe.sys_measure VALUES (49, 'UNWINDING_P', '');
INSERT INTO cfe.sys_measure VALUES (50, 'WRITE_DOWN_BALANCE', '');
INSERT INTO cfe.sys_measure VALUES (51, 'WRITE_DOWN_BALANCE_P', '');
INSERT INTO cfe.sys_measure VALUES (52, 'WRITE_DOWN_BALANCE_PP', '');
INSERT INTO cfe.sys_measure VALUES (53, 'WRITE_DOWN_D', '');
INSERT INTO cfe.sys_measure VALUES (54, 'WRITE_DOWN_DD', '');

--delete from cfe.sys_measure where ID_MEASURE>54;
INSERT INTO cfe.sys_measure VALUES (55, 'BEST_ESTIMATE', '');
INSERT INTO cfe.sys_measure VALUES (56, 'BEST_ESTIMATE_P', '');
INSERT INTO cfe.sys_measure VALUES (57, 'BEST_ESTIMATE_PP', '');
INSERT INTO cfe.sys_measure VALUES (58, 'BEST_ESTIMATE_D', '');
INSERT INTO cfe.sys_measure VALUES (59, 'BEST_ESTIMATE_DD', '');
INSERT INTO cfe.sys_measure VALUES (60, 'RISK_MARGIN', '');
INSERT INTO cfe.sys_measure VALUES (61, 'RISK_MARGIN_P', '');
INSERT INTO cfe.sys_measure VALUES (62, 'RISK_MARGIN_PP', '');
INSERT INTO cfe.sys_measure VALUES (63, 'RISK_MARGIN_D', '');
INSERT INTO cfe.sys_measure VALUES (64, 'RISK_MARGIN_DD', '');
INSERT INTO cfe.sys_measure VALUES (65, 'UNAMORTIZED_RESIDUAL_MARGIN', '');
INSERT INTO cfe.sys_measure VALUES (66, 'UNAMORTIZED_RESIDUAL_MARGIN_P', '');
INSERT INTO cfe.sys_measure VALUES (67, 'UNAMORTIZED_RESIDUAL_MARGIN_PP', '');
INSERT INTO cfe.sys_measure VALUES (68, 'UNAMORTIZED_RESIDUAL_MARGIN_D', '');
INSERT INTO cfe.sys_measure VALUES (69, 'UNAMORTIZED_RESIDUAL_MARGIN_DD', '');

INSERT INTO cfe.sys_measure VALUES (70, 'TRADE_RESULT', '');
INSERT INTO cfe.sys_measure VALUES (71, 'TRADE_RESULT_P', '');
INSERT INTO cfe.sys_measure VALUES (72, 'TRADE_RESULT_PP', '');
INSERT INTO cfe.sys_measure VALUES (73, 'TRADE_RESULT_D', '');
INSERT INTO cfe.sys_measure VALUES (74, 'TRADE_RESULT_DD', '');
INSERT INTO cfe.sys_measure VALUES (75, 'PREMISC', '');
INSERT INTO cfe.sys_measure VALUES (76, 'PREMISC_P', '');
INSERT INTO cfe.sys_measure VALUES (77, 'PREMISC_PP', '');
INSERT INTO cfe.sys_measure VALUES (78, 'PREMISC_D', '');
INSERT INTO cfe.sys_measure VALUES (79, 'PREMISC_DD', '');
INSERT INTO cfe.sys_measure VALUES (80, 'UNAMORTIZED_PREMISC', '');
INSERT INTO cfe.sys_measure VALUES (81, 'UNAMORTIZED_PREMISC_P', '');
INSERT INTO cfe.sys_measure VALUES (82, 'UNAMORTIZED_PREMISC_PP', '');
INSERT INTO cfe.sys_measure VALUES (83, 'UNAMORTIZED_PREMISC_D', '');
INSERT INTO cfe.sys_measure VALUES (84, 'UNAMORTIZED_PREMISC_DD', '');
INSERT INTO cfe.sys_measure VALUES (85, 'MARKET_PRICE_PORTION', '');
INSERT INTO cfe.sys_measure VALUES (86, 'MARKET_PRICE_PORTION_P', '');
INSERT INTO cfe.sys_measure VALUES (87, 'MARKET_PRICE_PORTION_PP', '');
INSERT INTO cfe.sys_measure VALUES (88, 'MARKET_PRICE_PORTION_D', '');
INSERT INTO cfe.sys_measure VALUES (89, 'MARKET_PRICE_PORTION_DD', '');
INSERT INTO cfe.sys_measure VALUES (90, 'CREDIT_SPREAD_PORTION', '');
INSERT INTO cfe.sys_measure VALUES (91, 'CREDIT_SPREAD_PORTION_P', '');
INSERT INTO cfe.sys_measure VALUES (92, 'CREDIT_SPREAD_PORTION_PP', '');
INSERT INTO cfe.sys_measure VALUES (93, 'CREDIT_SPREAD_PORTION_D', '');
INSERT INTO cfe.sys_measure VALUES (94, 'CREDIT_SPREAD_PORTION_DD', '');

---------------------------------------------------------------------------------------------------------------
-- DATA
CREATE TABLE cfe.instrument
  (
     id_instrument                VARCHAR(40) PRIMARY KEY NOT NULL
     , id_instrument_commitment   VARCHAR(40)
     , id_instrument_type         VARCHAR(12) NOT NULL
     , start_date                 DATE NOT NULL
     , end_date                   DATE
     , id_currency                VARCHAR(3) NOT NULL
     , id_calendar                VARCHAR(12)
     , id_business_day_convention VARCHAR(12)
     , discount_curve             VARCHAR(12)
     , discount_spread            VARCHAR(12)
  );

CREATE UNIQUE INDEX cfe.instrument_idx1
  ON cfe.instrument(id_instrument, id_instrument_commitment);

CREATE TABLE cfe.instrument_attribute
  (
     id_instrument     VARCHAR(40) NOT NULL
     , id_attribute    VARCHAR(40) NOT NULL
     , attribute_value VARCHAR(40)
  );

CREATE UNIQUE INDEX cfe.instrument_attribute_idx1
  ON cfe.instrument_attribute (id_instrument, id_attribute);

CREATE TABLE cfe.interest_period
  (
     id_instrument             VARCHAR(40) NOT NULL
     , id_fixingmode           SMALLINT DEFAULT 0 NOT NULL
     , fixing_date             DATE
     , change_date             DATE
     , base_rate               VARCHAR(12)
     , base_margin_rate        DECIMAL(12, 9)
     , par_rate                VARCHAR(12)
     , par_margin_rate         DECIMAL(12, 9)
     , id_payment_convention   VARCHAR(12)
     , id_day_count_convention VARCHAR(12)
     , id_day_incl_convention  VARCHAR(12)
     , fix_amount              DECIMAL(23, 5)
     , id_currency_fix_amount  VARCHAR(3)
     , id_script               VARCHAR(12)
  );

CREATE UNIQUE INDEX cfe.interest_period_idx1
  ON cfe.interest_period(id_instrument, change_date);

CREATE TABLE cfe.schedule
  (
     id_instrument                VARCHAR(40) NOT NULL
     , id_cashflow_type           VARCHAR(1) NOT NULL
     , id_fee_type                VARCHAR(12)
     , first_drop                 DATE
     , second_drop                DATE
     , enforce_eom                VARCHAR(1)
     , last_drop                  DATE
     , period_scalar              SMALLINT
     , id_period_type             VARCHAR(1)
     , id_business_day_convention VARCHAR(12)
     , amount                     DECIMAL(23, 5)
     , yield_enhancing_rate       DECIMAL(15, 9)
     , id_currency                VARCHAR(3)
  );

CREATE INDEX cfe.schedule_idx1
  ON cfe.schedule(id_instrument, first_drop);

CREATE TABLE cfe.one_time_payment
  (
     id_instrument                VARCHAR(40) NOT NULL
     , id_cashflow_type           VARCHAR(1) NOT NULL
     , id_fee_type                VARCHAR(12)
     , value_date                 DATE NOT NULL
     , id_business_day_convention VARCHAR(12)
     , amount                     DECIMAL(23, 5)
     , yield_enhancing_rate       DECIMAL(15, 9)
     , id_currency                VARCHAR(3)
     , start_date                 DATE
     , end_date                   DATE
  );

CREATE INDEX cfe.one_time_payment_idx1
  ON cfe.one_time_payment(id_instrument, value_date);

CREATE TABLE cfe.reconciliation_nominal
  (
     id_instrument     VARCHAR(40) NOT NULL
     , value_date      DATE NOT NULL
     , nominal_balance DECIMAL(23, 5) NOT NULL
  );

--@Krassimir, please advice
-- I have no conclusion on this table yet
-- especially I do not like the assign_date
-- do we need anything else here?
CREATE TABLE cfe.coll_impairment
  (
     id_instrument     VARCHAR(40) NOT NULL
     , id_portfolio    VARCHAR(40) NOT NULL
     , assignment_date DATE NOT NULL
     , default_date    DATE NOT NULL
  );

CREATE UNIQUE INDEX cfe.reconciliation_nominal_idx1
  ON cfe.reconciliation_nominal (id_instrument, value_date, nominal_balance);

CREATE TABLE cfe.scenario_cashflow (
	id_instrument				 VARCHAR(40)	NOT NULL
	, scenario				     VARCHAR(12)	NOT NULL
	, asset_liability_flag		 VARCHAR(1)		NOT NULL
	, id_cashflow_type           VARCHAR(1)		NOT NULL
    , id_fee_type                VARCHAR(12)
    , value_date                 DATE			NOT NULL
	, amount					 DECIMAL(23, 5) NOT NULL
	, id_currency                VARCHAR(3)		NOT NULL
);
CREATE INDEX cfe.scenario_cashflow_idx1
	ON cfe.scenario_cashflow (id_instrument);
CREATE INDEX cfe.scenario_cashflow_idx2
	ON cfe.scenario_cashflow (id_instrument, scenario, asset_liability_flag);

CREATE TABLE cfe.scenario_cf_probabilities (
	id_instrument				 VARCHAR(40)	NOT NULL
	, scenario				     VARCHAR(12)	NOT NULL
	, asset_liability_flag		 VARCHAR(1)		NOT NULL
	, valid_date				 DATE			NOT NULL
    , period_scalar				 SMALLINT		NOT NULL
    , id_period_type			 VARCHAR(1)		NOT NULL
    , rate						 DECIMAL(15, 9) NOT NULL
);
--  Issue 452: 	Unique index or primary key violation when using batch updates
--  http://code.google.com/p/h2database/issues/detail?can=2&start=0&num=100&q=&colspec=ID%20Type%20Status%20Priority%20Milestone%20Owner%20Summary&groupby=&sort=&id=452
--CREATE UNIQUE INDEX cfe.scenario_cf_probabilities_idx1
--on cfe.scenario_cf_probabilities (id_instrument, scenario, asset_liability_flag, valid_date, period_scalar, id_period_type);

CREATE TABLE cfe.instrument_import_measure
  (
     id_instrument                   VARCHAR(40) NOT NULL
     , id_measure					 SMALLINT NOT NULL
	 , value						 DECIMAL(23, 5)
  );
create unique index cfe.instrument_import_measure_idx1
on cfe.instrument_import_measure (id_instrument, id_measure);

CREATE TABLE cfe.instrument_price (
	id_instrument				VARCHAR(40) NOT NULL
	, valid_timestamp			TIMESTAMP NOT NULL
	, price						DECIMAL(23, 9) NOT NULL
	, id_price_type				VARCHAR(1) NOT NULL
	, valid_days				SMALLINT
);
CREATE UNIQUE INDEX instrument_price_idx1
on cfe.instrument_price (id_instrument, valid_timestamp);


CREATE TABLE cfe.transaction
  (
     id_instrument          VARCHAR(40) NOT NULL
     , id_transaction       VARCHAR(40) NOT NULL
     , value_date           DATE NOT NULL
     , settlement_date      DATE
     , quantity             DECIMAL(23, 5)
     , settlement_amount    DECIMAL(23, 5)
     , price                DECIMAL(23, 9)
     , clean_flag           VARCHAR(1) NOT NULL
  );

CREATE INDEX cfe.transaction_idx1
  ON cfe.transaction(id_instrument, value_date, id_transaction);

CREATE TABLE cfe.execution
  (
     start_timestamp    TIMESTAMP NOT NULL
     , end_timestamp    TIMESTAMP
     , value_date       DATE NOT NULL
     , version          BIGINT NOT NULL
     , value_date_p     DATE
     , value_date_pp    DATE
     , id_status        VARCHAR(1)
  );

CREATE INDEX cfe.execution_idx1
  ON cfe.execution(value_date, version);

CREATE TABLE cfe.instrument_measure_balance
  (
     id_instrument                       VARCHAR(40) NOT NULL
	 , id_position						 VARCHAR(40)
	 , asset_liability_flag				 VARCHAR(1) NOT NULL
     , report_date                       DATE NOT NULL
     , version                           BIGINT NOT NULL
     , nominal_balance                   DECIMAL(23, 5) NOT NULL
     , nominal_balance_bc                DECIMAL(23, 5) NOT NULL
     , nominal_balance_p                 DECIMAL(23, 5) NOT NULL
     , nominal_balance_p_bc              DECIMAL(23, 5) NOT NULL
     , nominal_balance_pp                DECIMAL(23, 5) NOT NULL
     , nominal_balance_pp_bc             DECIMAL(23, 5) NOT NULL
	 , nominal_balance_d				 DECIMAL(23, 5) NOT NULL
	 , nominal_balance_d_bc				 DECIMAL(23, 5) NOT NULL
	 , nominal_balance_dd				 DECIMAL(23, 5) NOT NULL
	 , nominal_balance_dd_bc			 DECIMAL(23, 5) NOT NULL
     , accrued_interest					 DECIMAL(23, 5) NOT NULL
     , accrued_interest_bc				 DECIMAL(23, 5) NOT NULL
     , accrued_interest_p				 DECIMAL(23, 5) NOT NULL
     , accrued_interest_p_bc			 DECIMAL(23, 5) NOT NULL
     , accrued_interest_pp				 DECIMAL(23, 5) NOT NULL
     , accrued_interest_pp_bc			 DECIMAL(23, 5) NOT NULL
	 , accrued_interest_d				 DECIMAL(23, 5) NOT NULL
     , accrued_interest_d_bc			 DECIMAL(23, 5) NOT NULL
     , accrued_interest_dd				 DECIMAL(23, 5) NOT NULL
     , accrued_interest_dd_bc			 DECIMAL(23, 5) NOT NULL
     , amortised_cost_dirty                    DECIMAL(23, 5) NOT NULL
     , amortised_cost_dirty_bc                 DECIMAL(23, 5) NOT NULL
     , amortised_cost_dirty_p                  DECIMAL(23, 5) NOT NULL
     , amortised_cost_dirty_p_bc               DECIMAL(23, 5) NOT NULL
     , amortised_cost_dirty_pp                 DECIMAL(23, 5) NOT NULL
     , amortised_cost_dirty_pp_bc              DECIMAL(23, 5) NOT NULL
	 , amortised_cost_clean                    DECIMAL(23, 5) NOT NULL
     , amortised_cost_clean_bc                 DECIMAL(23, 5) NOT NULL
     , amortised_cost_clean_p                  DECIMAL(23, 5) NOT NULL
     , amortised_cost_clean_p_bc               DECIMAL(23, 5) NOT NULL
     , amortised_cost_clean_pp                 DECIMAL(23, 5) NOT NULL
     , amortised_cost_clean_pp_bc              DECIMAL(23, 5) NOT NULL
     , fair_value_32_dirty					DECIMAL(23, 5)
     , fair_value_32_dirty_bc				DECIMAL(23, 5)
	 , fair_value_32_dirty_p				DECIMAL(23, 5)
     , fair_value_32_dirty_p_bc				DECIMAL(23, 5)
	 , fair_value_32_dirty_pp               DECIMAL(23, 5)
     , fair_value_32_dirty_pp_bc            DECIMAL(23, 5)
     , fair_value_32_clean					DECIMAL(23, 5)
     , fair_value_32_clean_bc				DECIMAL(23, 5)
	 , fair_value_32_clean_p				DECIMAL(23, 5)
     , fair_value_32_clean_p_bc				DECIMAL(23, 5)
	 , fair_value_32_clean_pp               DECIMAL(23, 5)
     , fair_value_32_clean_pp_bc            DECIMAL(23, 5)
     , fair_value_39_dirty					DECIMAL(23, 5)
     , fair_value_39_dirty_bc				DECIMAL(23, 5)
	 , fair_value_39_dirty_p				DECIMAL(23, 5)
     , fair_value_39_dirty_p_bc				DECIMAL(23, 5)
	 , fair_value_39_dirty_pp               DECIMAL(23, 5)
     , fair_value_39_dirty_pp_bc            DECIMAL(23, 5)
     , fair_value_39_clean					DECIMAL(23, 5)
     , fair_value_39_clean_bc				DECIMAL(23, 5)
	 , fair_value_39_clean_p				DECIMAL(23, 5)
     , fair_value_39_clean_p_bc				DECIMAL(23, 5)
	 , fair_value_39_clean_pp               DECIMAL(23, 5)
     , fair_value_39_clean_pp_bc            DECIMAL(23, 5)
     , receivable_principal					DECIMAL(23, 5) NOT NULL
     , receivable_principal_bc				DECIMAL(23, 5) NOT NULL
     , receivable_interest					DECIMAL(23, 5) NOT NULL
     , receivable_interest_bc				DECIMAL(23, 5) NOT NULL
     , receivable_fee						DECIMAL(23, 5) NOT NULL
     , receivable_fee_bc					DECIMAL(23, 5) NOT NULL
     , yield								DECIMAL(15, 12)
	 , yield_p								DECIMAL(15, 12)
	 , yield_pp                             DECIMAL(15, 12)
  );

CREATE UNIQUE INDEX cfe.instrument_measure_balance_idx1
  ON cfe.instrument_measure_balance(id_instrument, id_position, asset_liability_flag, report_date, version);

CREATE TABLE cfe.insurance_measure_balance
  (
     id_instrument							VARCHAR(40) NOT NULL
	 , asset_liability_flag					VARCHAR(1) NOT NULL
     , value_date							DATE NOT NULL
     , version								BIGINT NOT NULL
     , best_estimate						DECIMAL(23, 5) NOT NULL
     , best_estimate_bc						DECIMAL(23, 5) NOT NULL
     , best_estimate_p						DECIMAL(23, 5) NOT NULL
     , best_estimate_p_bc					DECIMAL(23, 5) NOT NULL
     , best_estimate_pp						DECIMAL(23, 5) NOT NULL
     , best_estimate_pp_bc					DECIMAL(23, 5) NOT NULL
	 , best_estimate_d						DECIMAL(23, 5) NOT NULL
	 , best_estimate_d_bc					DECIMAL(23, 5) NOT NULL
	 , best_estimate_dd						DECIMAL(23, 5) NOT NULL
	 , best_estimate_dd_bc					DECIMAL(23, 5) NOT NULL
     , risk_margin							DECIMAL(23, 5) NOT NULL
     , risk_margin_bc						DECIMAL(23, 5) NOT NULL
     , risk_margin_p						DECIMAL(23, 5) NOT NULL
     , risk_margin_p_bc						DECIMAL(23, 5) NOT NULL
     , risk_margin_pp						DECIMAL(23, 5) NOT NULL
     , risk_margin_pp_bc					DECIMAL(23, 5) NOT NULL
	 , risk_margin_d						DECIMAL(23, 5) NOT NULL
     , risk_margin_d_bc						DECIMAL(23, 5) NOT NULL
     , risk_margin_dd						DECIMAL(23, 5) NOT NULL
     , risk_margin_dd_bc					DECIMAL(23, 5) NOT NULL
     , unamortised_residual_margin          DECIMAL(23, 5) NOT NULL
     , unamortised_residual_margin_bc       DECIMAL(23, 5) NOT NULL
     , unamortised_residual_margin_p        DECIMAL(23, 5) NOT NULL
     , unamortised_residual_margin_p_bc     DECIMAL(23, 5) NOT NULL
     , unamortised_residual_margin_pp       DECIMAL(23, 5) NOT NULL
     , unamortised_residual_margin_pp_bc    DECIMAL(23, 5) NOT NULL
	 , unamortised_residual_margin_d        DECIMAL(23, 5) NOT NULL
     , unamortised_residual_margin_d_bc     DECIMAL(23, 5) NOT NULL
     , unamortised_residual_margin_dd       DECIMAL(23, 5) NOT NULL
     , unamortised_residual_margin_dd_bc    DECIMAL(23, 5) NOT NULL
     , yield								DECIMAL(15, 12)
  );
CREATE UNIQUE INDEX cfe.insurance_measure_balance_idx1
  ON cfe.insurance_measure_balance(id_instrument, asset_liability_flag, value_date, version);

CREATE TABLE cfe.instrument_measure_income
  (
     id_instrument                       VARCHAR(40) NOT NULL
	 , id_position						 VARCHAR(40)
	 , asset_liability_flag				 VARCHAR(1) NOT NULL
     , report_date                       DATE NOT NULL
     , version                           BIGINT NOT NULL
     , interest							 DECIMAL(23, 5) NOT NULL
     , interest_bc						 DECIMAL(23, 5) NOT NULL
     , interest_p						 DECIMAL(23, 5) NOT NULL
     , interest_p_bc					 DECIMAL(23, 5) NOT NULL
     , interest_pp						 DECIMAL(23, 5) NOT NULL
     , interest_pp_bc					 DECIMAL(23, 5) NOT NULL
	 , interest_d						 DECIMAL(23, 5) NOT NULL
     , interest_d_bc					 DECIMAL(23, 5) NOT NULL
     , interest_dd						 DECIMAL(23, 5) NOT NULL
     , interest_dd_bc					 DECIMAL(23, 5) NOT NULL
     , interest_smoothing                DECIMAL(23, 5) NOT NULL
     , interest_smoothing_bc             DECIMAL(23, 5) NOT NULL
     , interest_smoothing_p              DECIMAL(23, 5) NOT NULL
     , interest_smoothing_p_bc           DECIMAL(23, 5) NOT NULL
     , interest_smoothing_pp             DECIMAL(23, 5) NOT NULL
     , interest_smoothing_pp_bc          DECIMAL(23, 5) NOT NULL
	 , interest_smoothing_d              DECIMAL(23, 5) NOT NULL
     , interest_smoothing_d_bc           DECIMAL(23, 5) NOT NULL
     , interest_smoothing_dd             DECIMAL(23, 5) NOT NULL
     , interest_smoothing_dd_bc          DECIMAL(23, 5) NOT NULL
	 , penalty_interest					 DECIMAL(23, 5) NOT NULL
	 , penalty_interest_bc				 DECIMAL(23, 5) NOT NULL
	 , penalty_interest_p				 DECIMAL(23, 5) NOT NULL
	 , penalty_interest_p_bc			 DECIMAL(23, 5) NOT NULL
	 , penalty_interest_pp				 DECIMAL(23, 5) NOT NULL
	 , penalty_interest_pp_bc			 DECIMAL(23, 5) NOT NULL
	 , penalty_interest_d				 DECIMAL(23, 5) NOT NULL
	 , penalty_interest_d_bc			 DECIMAL(23, 5) NOT NULL
	 , penalty_interest_dd				 DECIMAL(23, 5) NOT NULL
	 , penalty_interest_dd_bc			 DECIMAL(23, 5) NOT NULL
  );
CREATE UNIQUE INDEX cfe.instrument_measure_income_idx1
  ON cfe.instrument_measure_income(id_instrument, id_position, asset_liability_flag, report_date, version);

CREATE TABLE cfe.instrument_measure_impairment
  (
     id_instrument                       VARCHAR(40) NOT NULL
	 , id_position						 VARCHAR(40)
	 , asset_liability_flag				 VARCHAR(1) NOT NULL
     , report_date                       DATE NOT NULL
     , version                           BIGINT NOT NULL
	 , recovery_balance				     DECIMAL(23, 5) NOT NULL
	 , recovery_balance_bc				 DECIMAL(23, 5) NOT NULL
	 , recovery_balance_p				 DECIMAL(23, 5) NOT NULL
	 , recovery_balance_p_bc		     DECIMAL(23, 5) NOT NULL
	 , recovery_balance_pp				 DECIMAL(23, 5) NOT NULL
	 , recovery_balance_pp_bc		     DECIMAL(23, 5) NOT NULL
	 , recovery_balance_d				 DECIMAL(23, 5) NOT NULL
	 , recovery_balance_d_bc		     DECIMAL(23, 5) NOT NULL
	 , recovery_balance_dd				 DECIMAL(23, 5) NOT NULL
	 , recovery_balance_dd_bc		     DECIMAL(23, 5) NOT NULL
	 , write_down						 DECIMAL(23, 5) NOT NULL
	 , write_down_bc					 DECIMAL(23, 5) NOT NULL
	 , write_down_p						 DECIMAL(23, 5) NOT NULL
	 , write_down_p_bc					 DECIMAL(23, 5) NOT NULL
	 , write_down_pp					 DECIMAL(23, 5) NOT NULL
	 , write_down_pp_bc					 DECIMAL(23, 5) NOT NULL
	 , write_down_d						 DECIMAL(23, 5) NOT NULL
	 , write_down_d_bc					 DECIMAL(23, 5) NOT NULL
	 , write_down_dd					 DECIMAL(23, 5) NOT NULL
	 , write_down_dd_bc					 DECIMAL(23, 5) NOT NULL
     , impairment                        DECIMAL(23, 5) NOT NULL
     , impairment_bc                     DECIMAL(23, 5) NOT NULL
	 , impairment_p                      DECIMAL(23, 5) NOT NULL
     , impairment_p_bc                   DECIMAL(23, 5) NOT NULL
	 , impairment_pp                     DECIMAL(23, 5) NOT NULL
     , impairment_pp_bc                  DECIMAL(23, 5) NOT NULL
	 , impairment_d                      DECIMAL(23, 5) NOT NULL
     , impairment_d_bc                   DECIMAL(23, 5) NOT NULL
	 , impairment_dd                     DECIMAL(23, 5) NOT NULL
     , impairment_dd_bc                  DECIMAL(23, 5) NOT NULL
     , impairment_is_specific            VARCHAR(1) NOT NULL
     , unwinding                         DECIMAL(23, 5) NOT NULL
     , unwinding_bc                      DECIMAL(23, 5) NOT NULL
	 , unwinding_p                       DECIMAL(23, 5) NOT NULL
     , unwinding_p_bc                    DECIMAL(23, 5) NOT NULL
	 , unwinding_pp                      DECIMAL(23, 5) NOT NULL
     , unwinding_pp_bc                   DECIMAL(23, 5) NOT NULL
	 , unwinding_d                       DECIMAL(23, 5) NOT NULL
     , unwinding_d_bc                    DECIMAL(23, 5) NOT NULL
	 , unwinding_dd                      DECIMAL(23, 5) NOT NULL
     , unwinding_dd_bc                   DECIMAL(23, 5) NOT NULL
  );

CREATE UNIQUE INDEX cfe.instrument_measure_impairment_idx1
  ON cfe.instrument_measure_impairment(id_instrument, id_position, asset_liability_flag, report_date, version);

CREATE TABLE cfe.position_measure
  (
       id_instrument                       VARCHAR(40) NOT NULL
	 , id_position						 VARCHAR(40)
	 , asset_liability_flag				 VARCHAR(1) NOT NULL
     , report_date                       DATE NOT NULL
     , version                           BIGINT NOT NULL
	 , trade_result				     DECIMAL(23, 5) NOT NULL
	 , trade_result_bc				 DECIMAL(23, 5) NOT NULL
	 , trade_result_p				 DECIMAL(23, 5) NOT NULL
	 , trade_result_p_bc		     DECIMAL(23, 5) NOT NULL
	 , trade_result_pp				 DECIMAL(23, 5) NOT NULL
	 , trade_result_pp_bc		     DECIMAL(23, 5) NOT NULL
	 , trade_result_d				 DECIMAL(23, 5) NOT NULL
	 , trade_result_d_bc		     DECIMAL(23, 5) NOT NULL
	 , trade_result_dd				 DECIMAL(23, 5) NOT NULL
	 , trade_result_dd_bc		     DECIMAL(23, 5) NOT NULL
	 , premdisc						 DECIMAL(23, 5) NOT NULL
	 , premdisc_bc					 DECIMAL(23, 5) NOT NULL
	 , premdisc_p						 DECIMAL(23, 5) NOT NULL
	 , premdisc_p_bc					 DECIMAL(23, 5) NOT NULL
	 , premdisc_pp					 DECIMAL(23, 5) NOT NULL
	 , premdisc_pp_bc					 DECIMAL(23, 5) NOT NULL
	 , premdisc_d						 DECIMAL(23, 5) NOT NULL
	 , premdisc_d_bc					 DECIMAL(23, 5) NOT NULL
	 , premdisc_dd					 DECIMAL(23, 5) NOT NULL
	 , premdisc_dd_bc					 DECIMAL(23, 5) NOT NULL
	 , unamortized_premdisc						 DECIMAL(23, 5) NOT NULL
	 , unamortized_premdisc_bc					 DECIMAL(23, 5) NOT NULL
	 , unamortized_premdisc_p						 DECIMAL(23, 5) NOT NULL
	 , unamortized_premdisc_p_bc					 DECIMAL(23, 5) NOT NULL
	 , unamortized_premdisc_pp					 DECIMAL(23, 5) NOT NULL
	 , unamortized_premdisc_pp_bc					 DECIMAL(23, 5) NOT NULL
	 , unamortized_premdisc_d						 DECIMAL(23, 5) NOT NULL
	 , unamortized_premdisc_d_bc					 DECIMAL(23, 5) NOT NULL
	 , unamortized_premdisc_dd					 DECIMAL(23, 5) NOT NULL
	 , unamortized_premdisc_dd_bc					 DECIMAL(23, 5) NOT NULL
     , market_price_portion                        DECIMAL(23, 5) NOT NULL
     , market_price_portion_bc                     DECIMAL(23, 5) NOT NULL
	 , market_price_portion_p                      DECIMAL(23, 5) NOT NULL
     , market_price_portion_p_bc                   DECIMAL(23, 5) NOT NULL
	 , market_price_portion_pp                     DECIMAL(23, 5) NOT NULL
     , market_price_portion_pp_bc                  DECIMAL(23, 5) NOT NULL
	 , market_price_portion_d                      DECIMAL(23, 5) NOT NULL
     , market_price_portion_d_bc                   DECIMAL(23, 5) NOT NULL
	 , market_price_portion_dd                     DECIMAL(23, 5) NOT NULL
     , market_price_portion_dd_bc                  DECIMAL(23, 5) NOT NULL
     , credit_spread_portion                         DECIMAL(23, 5) NOT NULL
     , credit_spread_portion_bc                      DECIMAL(23, 5) NOT NULL
	 , credit_spread_portion_p                       DECIMAL(23, 5) NOT NULL
     , credit_spread_portion_p_bc                    DECIMAL(23, 5) NOT NULL
	 , credit_spread_portion_pp                      DECIMAL(23, 5) NOT NULL
     , credit_spread_portion_pp_bc                   DECIMAL(23, 5) NOT NULL
	 , credit_spread_portion_d                       DECIMAL(23, 5) NOT NULL
     , credit_spread_portion_d_bc                    DECIMAL(23, 5) NOT NULL
	 , credit_spread_portion_dd                      DECIMAL(23, 5) NOT NULL
     , credit_spread_portion_dd_bc                   DECIMAL(23, 5) NOT NULL
	 , latest_disc_spread							 DECIMAL(23,15)
	 , latest_disc_spread_p							 DECIMAL(23,15)
	 , latest_disc_spread_pp						 DECIMAL(23,15)
	 , avg_hst_disc_spread							 DECIMAL(23,15)
	 , avg_hst_disc_spread_p						 DECIMAL(23,15)
	 , avg_hst_disc_spread_pp						 DECIMAL(23,15)
  );

CREATE UNIQUE INDEX cfe.position_measure_idx1
  ON cfe.position_measure(id_instrument, id_position, asset_liability_flag, report_date, version);

CREATE TABLE cfe.instrument_measure_fee
  (
     id_instrument              VARCHAR(40) NOT NULL
	 , id_position				VARCHAR(40)
	 , asset_liability_flag		VARCHAR(1) NOT NULL
     , report_date              DATE NOT NULL
     , version                  BIGINT NOT NULL
     , id_feetype               VARCHAR(12)
     , fee						DECIMAL(23, 5) NOT NULL
     , fee_bc					DECIMAL(23, 5) NOT NULL
     , fee_p					DECIMAL(23, 5) NOT NULL
     , fee_p_bc					DECIMAL(23, 5) NOT NULL
     , fee_pp					DECIMAL(23, 5) NOT NULL
     , fee_pp_bc				DECIMAL(23, 5) NOT NULL
	 , fee_d					DECIMAL(23, 5) NOT NULL
     , fee_d_bc					DECIMAL(23, 5) NOT NULL
     , fee_dd					DECIMAL(23, 5) NOT NULL
     , fee_dd_bc				DECIMAL(23, 5) NOT NULL
     , unamortized_fee          DECIMAL(23, 5) NOT NULL
     , unamortized_fee_bc       DECIMAL(23, 5) NOT NULL
     , unamortized_fee_p        DECIMAL(23, 5) NOT NULL
     , unamortized_fee_p_bc     DECIMAL(23, 5) NOT NULL
     , unamortized_fee_pp       DECIMAL(23, 5) NOT NULL
     , unamortized_fee_pp_bc    DECIMAL(23, 5) NOT NULL
	 , unamortized_fee_d        DECIMAL(23, 5) NOT NULL
     , unamortized_fee_d_bc     DECIMAL(23, 5) NOT NULL
     , unamortized_fee_dd       DECIMAL(23, 5) NOT NULL
     , unamortized_fee_dd_bc    DECIMAL(23, 5) NOT NULL
     , fee_sl					DECIMAL(23, 5) NOT NULL
     , fee_sl_bc				DECIMAL(23, 5) NOT NULL
     , fee_sl_p					DECIMAL(23, 5) NOT NULL
     , fee_sl_p_bc				DECIMAL(23, 5) NOT NULL
     , fee_sl_pp				DECIMAL(23, 5) NOT NULL
     , fee_sl_pp_bc				DECIMAL(23, 5) NOT NULL
	 , fee_sl_d					DECIMAL(23, 5) NOT NULL
     , fee_sl_d_bc				DECIMAL(23, 5) NOT NULL
     , fee_sl_dd				DECIMAL(23, 5) NOT NULL
     , fee_sl_dd_bc				DECIMAL(23, 5) NOT NULL
     , unamortized_fee_sl       DECIMAL(23, 5) NOT NULL
     , unamortized_fee_sl_bc    DECIMAL(23, 5) NOT NULL
     , unamortized_fee_sl_p     DECIMAL(23, 5) NOT NULL
     , unamortized_fee_sl_p_bc  DECIMAL(23, 5) NOT NULL
     , unamortized_fee_sl_pp    DECIMAL(23, 5) NOT NULL
     , unamortized_fee_sl_pp_bc DECIMAL(23, 5) NOT NULL
	 , unamortized_fee_sl_d     DECIMAL(23, 5) NOT NULL
     , unamortized_fee_sl_d_bc  DECIMAL(23, 5) NOT NULL
     , unamortized_fee_sl_dd    DECIMAL(23, 5) NOT NULL
     , unamortized_fee_sl_dd_bc DECIMAL(23, 5) NOT NULL
     , fee_pl					DECIMAL(23, 5) NOT NULL
     , fee_pl_bc				DECIMAL(23, 5) NOT NULL
     , fee_pl_p					DECIMAL(23, 5) NOT NULL
     , fee_pl_p_bc				DECIMAL(23, 5) NOT NULL
     , fee_pl_pp				DECIMAL(23, 5) NOT NULL
     , fee_pl_pp_bc				DECIMAL(23, 5) NOT NULL
	 , fee_pl_d					DECIMAL(23, 5) NOT NULL
     , fee_pl_d_bc				DECIMAL(23, 5) NOT NULL
     , fee_pl_dd				DECIMAL(23, 5) NOT NULL
     , fee_pl_dd_bc				DECIMAL(23, 5) NOT NULL
  );

CREATE UNIQUE INDEX cfe.instrument_measure_fee_idx1
  ON cfe.instrument_measure_fee(id_instrument, id_position, asset_liability_flag, report_date, version, id_feetype);

CREATE TABLE cfe.accounting_scope (
	id_accounting_scope SMALLINT PRIMARY KEY NOT NULL
	, description VARCHAR(255)
);
INSERT INTO cfe.accounting_scope VALUES (1, 'International Financial Reporting Standard (IFRS)');

--drop table cfe.accounting_event;
CREATE TABLE cfe.accounting_event (
	id_accounting_event SMALLINT PRIMARY KEY NOT NULL
	, id_accounting_scope  SMALLINT NOT NULL
	, id_instrument_type VARCHAR(12)
	, id_measure_previous VARCHAR(255)
	, id_measure_current VARCHAR(255) NOT NULL
	, id_measure_current_2 VARCHAR(255)
	, asset_liability_flag VARCHAR(1)
	, same_period_flag VARCHAR(1)
	, sign_flag VARCHAR(1)
	, code_debit_account VARCHAR(40) NOT NULL
	, code_credit_account VARCHAR(40) NOT NULL
	, value_date_flag VARCHAR(1)
	, description clob
);
create index cfe.accounting_event_idx1
on cfe.accounting_event(id_accounting_scope, id_instrument_type);

delete from cfe.accounting_event;
insert into cfe.accounting_event values(1, 1, 'loan', '', 'NOMINAL_BALANCE', 'NOMINAL_BALANCE_P', 'A', '', '', '01.07.000001', '0x.0x.999999', 'R', 'Loan payment of principle');
insert into cfe.accounting_event values(2, 1, 'loan', 'NOMINAL_BALANCE_D', 'NOMINAL_BALANCE_DD', '', 'A', 'Y', '', '01.07.000001', '0x.0x.999999', 'P', 'Loan payment of principle (correction of previous day balances)');
insert into cfe.accounting_event values(3, 1, 'loan', 'NOMINAL_BALANCE_PP', 'NOMINAL_BALANCE_PP', '', 'A', 'Y', '', '01.07.000001', '0x.0x.999999', 'E', 'Loan payment of principle (correction of last EOY balances)');
insert into cfe.accounting_event values(4, 1, 'loan', 'NOMINAL_BALANCE', 'NOMINAL_BALANCE_PP', '', 'A', 'N', '', '01.07.000001', '0x.0x.999999', 'E', 'Loan payment of principle (correction of last EOY balances)');
insert into cfe.accounting_event values(5, 1, 'loan', '', 'INTEREST_D', 'INTEREST_DD', 'A', '', '', '06.01.700001', '0x.0x.999999', 'R', 'Loan payment of interest');
insert into cfe.accounting_event values(6, 1, 'loan', 'INTEREST_D', 'INTEREST_DD', '', 'A', 'Y', '', '06.01.700001', '0x.0x.999999', 'P', 'Loan payment of interest (correction of previous day income)');
insert into cfe.accounting_event values(7, 1, 'loan', '', 'FEE_D', 'FEE_DD', 'A', '', '', '06.01.700003', '0x.0x.999999', 'R', 'Loan payment of fees to be amortized');
insert into cfe.accounting_event values(8, 1, 'loan', 'FEE_D', 'FEE_DD', '', 'A', 'Y', '', '06.01.700003', '0x.0x.999999', 'P', 'Loan payment of fees to be amortized (correction of previous day balances)');
insert into cfe.accounting_event values(9, 1, 'loan', 'FEE_PP', 'FEE_PP', '', 'A', 'Y', '', '06.01.700003', '0x.0x.999999', 'E', 'Loan payment of fees to be amortized (correction of last EOY balances)');
insert into cfe.accounting_event values(10, 1, 'loan', 'FEE', 'FEE_PP', '', 'A', 'N', '', '06.01.700003', '0x.0x.999999', 'E', 'Loan payment of fees to be amortized (correction of last EOY balances)');
insert into cfe.accounting_event values(11, 1, 'loan', '', 'FEE_SL_D', 'FEE_SL_DD', 'A', '', '', '06.01.700004', '0x.0x.999999', 'R', 'Loan payment of fees to be amortized SL');
insert into cfe.accounting_event values(12, 1, 'loan', 'FEE_SL_D', 'FEE_SL_DD', '', 'A', 'Y', '', '06.01.700004', '0x.0x.999999', 'P', 'Loan payment of fees to be amortized SL (correction of previous day balances)');
insert into cfe.accounting_event values(13, 1, 'loan', 'FEE_SL_PP', 'FEE_SL_PP', '', 'A', 'Y', '', '06.01.700004', '0x.0x.999999', 'E', 'Loan payment of fees to be amortized SL (correction of last EOY balances)');
insert into cfe.accounting_event values(14, 1, 'loan', 'FEE_SL', 'FEE_SL_PP', '', 'A', 'N', '', '06.01.700004', '0x.0x.999999', 'E', 'Loan payment of fees to be amortized SL (correction of last EOY balances)');
insert into cfe.accounting_event values(15, 1, 'loan', '', 'FEE_PL_D', 'FEE_PL_DD', 'A', '', '', '06.02.700001', '0x.0x.999999', 'R', 'Loan payment of fee direct P&L (incoming)');
insert into cfe.accounting_event values(16, 1, 'loan', 'FEE_PL_D', 'FEE_PL_DD', '', 'A', 'Y', '', '06.02.700001', '0x.0x.999999', 'R', 'Loan payment of fee direct P&L (incoming)');
insert into cfe.accounting_event values(17, 1, 'loan', '', 'FEE_D', 'FEE_DD', 'L', '', '', '06.03.720003', '0x.0x.999999', 'R', 'Loan payment of fees to be amortized');
insert into cfe.accounting_event values(18, 1, 'loan', 'FEE_D', 'FEE_DD', '', 'L', 'Y', '', '06.03.720003', '0x.0x.999999', 'P', 'Loan payment of fees to be amortized (correction of previous day balances)');
insert into cfe.accounting_event values(19, 1, 'loan', 'FEE_PP', 'FEE_PP', '', 'L', 'Y', '', '06.03.720003', '0x.0x.999999', 'E', 'Loan payment of fees to be amortized (correction of last EOY balances)');
insert into cfe.accounting_event values(20, 1, 'loan', 'FEE', 'FEE_PP', '', 'L', 'N', '', '06.03.720003', '0x.0x.999999', 'E', 'Loan payment of fees to be amortized (correction of last EOY balances)');
insert into cfe.accounting_event values(21, 1, 'loan', '', 'FEE_SL_D', 'FEE_SL_DD', 'L', '', '', '06.03.720004', '0x.0x.999999', 'R', 'Loan payment of fees to be amortized SL');
insert into cfe.accounting_event values(22, 1, 'loan', 'FEE_SL_D', 'FEE_SL_DD', '', 'L', 'Y', '', '06.03.720004', '0x.0x.999999', 'P', 'Loan payment of fees to be amortized SL (correction of previous day balances)');
insert into cfe.accounting_event values(23, 1, 'loan', 'FEE_SL_PP', 'FEE_SL_PP', '', 'L', 'Y', '', '06.03.720004', '0x.0x.999999', 'E', 'Loan payment of fees to be amortized SL (correction of last EOY balances)');
insert into cfe.accounting_event values(24, 1, 'loan', 'FEE_SL', 'FEE_SL_PP', '', 'L', 'N', '', '06.03.720004', '0x.0x.999999', 'E', 'Loan payment of fees to be amortized SL (correction of last EOY balances)');
insert into cfe.accounting_event values(25, 1, 'loan', '', 'FEE_PL_D', 'FEE_PL_DD', 'L', '', '', '06.04.700001', '0x.0x.999999', 'R', 'Loan payment of fee direct P&L (incoming)');
insert into cfe.accounting_event values(26, 1, 'loan', 'FEE_PL_D', 'FEE_PL_DD', '', 'L', 'Y', '', '06.04.700001', '0x.0x.999999', 'R', 'Loan payment of fee direct P&L (incoming)');
insert into cfe.accounting_event values(27, 1, 'loan', '', 'PENALTY_INTEREST_D', 'PENALTY_INTEREST_DD', 'A', '', '', '06.01.700013', '0x.0x.999999', 'R', 'Loan payment of interest');
insert into cfe.accounting_event values(28, 1, 'loan', 'PENALTY_INTEREST_D', 'PENALTY_INTEREST_DD', '', 'A', 'Y', '', '06.01.700013', '0x.0x.999999', 'P', 'Loan payment of interest (correction of previous day income)');
insert into cfe.accounting_event values(29, 1, 'loan', '', 'RECOVERY_BALANCE', 'RECOVERY_BALANCE_P', 'A', '', '', '01.07.000001', '0x.0x.999999', 'R', 'Loan payment of actual recovery in impairment');
insert into cfe.accounting_event values(30, 1, 'loan', 'RECOVERY_BALANCE_D', 'RECOVERY_BALANCE_DD', '', 'A', 'Y', '', '01.07.000001', '0x.0x.999999', 'P', 'Loan payment of actual recovery (correction of previous day balances)');
insert into cfe.accounting_event values(31, 1, 'loan', 'RECOVERY_BALANCE_PP', 'RECOVERY_BALANCE_PP', '', 'A', 'Y', '', '01.07.000001', '0x.0x.999999', 'E', 'Loan payment of actual recovery (correction of last EOY balances)');
insert into cfe.accounting_event values(32, 1, 'loan', 'RECOVERY_BALANCE', 'RECOVERY_BALANCE_PP', '', 'A', 'N', '', '01.07.000001', '0x.0x.999999', 'E', 'Loan payment of actual recovery (correction of last EOY balances)');
insert into cfe.accounting_event values(33, 1, 'loan', '', 'WRITE_DOWN', 'WRITE_DOWN_P', 'A', '', '', '01.07.000001', '06.05.000001', 'R', 'Loan partial write down in impairment');
insert into cfe.accounting_event values(34, 1, 'loan', 'WRITE_DOWN_D', 'WRITE_DOWN_DD', '', 'A', 'Y', '', '01.07.000001', '06.05.000001', 'P', 'Loan partial write down (correction of previous day balances)');
insert into cfe.accounting_event values(35, 1, 'loan', 'WRITE_DOWN_PP', 'WRITE_DOWN_PP', '', 'A', 'Y', '', '01.07.000001', '06.05.000001', 'E', 'Loan partial write down (correction of last EOY balances)');
insert into cfe.accounting_event values(36, 1, 'loan', 'WRITE_DOWN', 'WRITE_DOWN_PP', '', 'A', 'N', '', '01.07.000001', '06.05.000001', 'E', 'Loan partial write down (correction of last EOY balances)');
insert into cfe.accounting_event values(37, 1, 'loan', '', 'UNWINDING', 'UNWINDING_P', 'A', '', '', '06.01.700007', '01.07.000011', 'R', 'Loan unwinding income (impairment)');
insert into cfe.accounting_event values(38, 1, 'loan', 'UNWINDING', 'UNWINDING_P', '', 'A', 'Y', '', '06.01.700007', '01.07.000011', 'P', 'Loan unwinding income (impairment) (correction of previous day income)');
insert into cfe.accounting_event values(39, 1, 'loan', '', 'IMPAIRMENT', 'IMPAIRMENT_P', 'A', '', '', '06.05.000001', '01.07.000011', 'R', 'Loan unwinding income (impairment)');
insert into cfe.accounting_event values(40, 1, 'loan', 'IMPAIRMENT', 'IMPAIRMENT_P', '', 'A', 'Y', '', '06.05.000001', '01.07.000011', 'P', 'Loan unwinding income (impairment) (correction of previous day income)');
--insert into cfe.accounting_event values(41, 1, '', 'D/C entry to set all BS accounts of 0 against Impairment Expense (P&L)', '', '', '', '', '', '06.01.700001', '', '', '');
insert into cfe.accounting_event values(42, 1, 'loan', '', 'ACCRUED_INTEREST', 'ACCRUED_INTEREST_P', 'A', '', '', '01.07.000002', '06.01.700001', 'R', 'Loan accrual of interest');
insert into cfe.accounting_event values(43, 1, 'loan', 'ACCRUED_INTEREST_D', 'ACCRUED_INTEREST_DD', '', 'A', 'Y', '', '01.07.000002', '06.01.700001', 'P', 'Loan accrual of interest (correction of previous day income)');
insert into cfe.accounting_event values(44, 1, 'loan', 'ACCRUED_INTEREST_PP', 'ACCRUED_INTEREST_PP', '', 'A', 'Y', '', '01.07.000002', '06.01.700001', 'E', 'Loan accrual of interest (correction of last EOY balances)');
insert into cfe.accounting_event values(45, 1, 'loan', 'ACCRUED_INTEREST', 'ACCRUED_INTEREST_PP', '', 'A', 'N', '', '01.07.000002', '06.01.700001', 'E', 'Loan accrual of interest (correction of last EOY balances)');
insert into cfe.accounting_event values(46, 1, 'loan', '', 'UNAMORTIZED_FEE', 'UNAMORTIZED_FEE_P', 'A', '', '', '01.07.000004', '06.01.700003', 'R', 'Loan amortization of fees');
insert into cfe.accounting_event values(47, 1, 'loan', 'UNAMORTIZED_FEE_D', 'UNAMORTIZED_FEE_DD', '', 'A', 'Y', '', '01.07.000004', '06.01.700003', 'P', 'Loan amortization of fees (correction of previous day income)');
insert into cfe.accounting_event values(48, 1, 'loan', 'UNAMORTIZED_FEE_PP', 'UNAMORTIZED_FEE_PP', '', 'A', 'Y', '', '01.07.000004', '06.01.700003', 'E', 'Loan amortization of fees (correction of last EOY balances)');
insert into cfe.accounting_event values(49, 1, 'loan', 'UNAMORTIZED_FEE', 'UNAMORTIZED_FEE_PP', '', 'A', 'N', '', '01.07.000004', '06.01.700003', 'E', 'Loan amortization of fees (correction of last EOY balances)');
insert into cfe.accounting_event values(50, 1, 'loan', '', 'UNAMORTIZED_FEE_SL', 'UNAMORTIZED_FEE_SL_P', 'A', '', '', '01.07.000005', '06.01.700004', 'R', 'Loan amortization of fees SL');
insert into cfe.accounting_event values(51, 1, 'loan', 'UNAMORTIZED_FEE_SL_D', 'UNAMORTIZED_FEE_SL_DD', '', 'A', 'Y', '', '01.07.000005', '06.01.700004', 'P', 'Loan amortization of fees SL (correction of previous day income)');
insert into cfe.accounting_event values(52, 1, 'loan', 'UNAMORTIZED_FEE_SL_PP', 'UNAMORTIZED_FEE_SL_PP', '', 'A', 'Y', '', '01.07.000005', '06.01.700004', 'E', 'Loan amortization of fees SL (correction of last EOY balances)');
insert into cfe.accounting_event values(53, 1, 'loan', 'UNAMORTIZED_FEE_SL', 'UNAMORTIZED_FEE_SL_PP', '', 'A', 'N', '', '01.07.000005', '06.01.700004', 'E', 'Loan amortization of fees SL (correction of last EOY balances)');
insert into cfe.accounting_event values(54, 1, 'loan', '', 'INTEREST_SMOOTHING', 'INTEREST_SMOOTHING_P', 'A', '', '', '01.07.000006', '06.01.700005', 'R', 'Loan interest smoothing');
insert into cfe.accounting_event values(55, 1, 'loan', 'INTEREST_SMOOTHING_D', 'INTEREST_SMOOTHING_DD', '', 'A', 'Y', '', '01.07.000006', '06.01.700005', 'P', 'Loan interest smoothing (correction of previous day income)');
insert into cfe.accounting_event values(56, 1, 'loan', 'INTEREST_SMOOTHING_PP', 'INTEREST_SMOOTHING_PP', '', 'A', 'Y', '', '01.07.000006', '06.01.700005', 'E', 'Loan interest smoothing (correction of last EOY balances)');
insert into cfe.accounting_event values(57, 1, 'loan', 'INTEREST_SMOOTHING', 'INTEREST_SMOOTHING_PP', '', 'A', 'N', '', '01.07.000006', '06.01.700005', 'E', 'Loan nterest smoothing (correction of last EOY balances)');
insert into cfe.accounting_event values(58, 1, 'loan', '', 'UNAMORTIZED_FEE', 'UNAMORTIZED_FEE_P', 'L', '', '', '01.07.000004', '06.03.720003', 'R', 'Loan amortization of fees');
insert into cfe.accounting_event values(59, 1, 'loan', 'UNAMORTIZED_FEE_D', 'UNAMORTIZED_FEE_DD', '', 'L', 'Y', '', '01.07.000004', '06.03.720003', 'P', 'Loan amortization of fees (correction of previous day income)');
insert into cfe.accounting_event values(60, 1, 'loan', 'UNAMORTIZED_FEE_PP', 'UNAMORTIZED_FEE_PP', '', 'L', 'Y', '', '01.07.000004', '06.03.720003', 'E', 'Loan amortization of fees (correction of last EOY balances)');
insert into cfe.accounting_event values(61, 1, 'loan', 'UNAMORTIZED_FEE', 'UNAMORTIZED_FEE_PP', '', 'L', 'N', '', '01.07.000004', '06.03.720003', 'E', 'Loan amortization of fees (correction of last EOY balances)');
insert into cfe.accounting_event values(62, 1, 'loan', '', 'UNAMORTIZED_FEE_SL', 'UNAMORTIZED_FEE_SL_P', 'L', '', '', '01.07.000005', '06.03.720004', 'R', 'Loan amortization of fees SL');
insert into cfe.accounting_event values(63, 1, 'loan', 'UNAMORTIZED_FEE_SL_D', 'UNAMORTIZED_FEE_SL_DD', '', 'L', 'Y', '', '01.07.000005', '06.03.720004', 'P', 'Loan amortization of fees SL (correction of previous day income)');
insert into cfe.accounting_event values(64, 1, 'loan', 'UNAMORTIZED_FEE_SL_PP', 'UNAMORTIZED_FEE_SL_PP', '', 'L', 'Y', '', '01.07.000005', '06.03.720004', 'E', 'Loan amortization of fees SL (correction of last EOY balances)');
insert into cfe.accounting_event values(65, 1, 'loan', 'UNAMORTIZED_FEE_SL', 'UNAMORTIZED_FEE_SL_PP', '', 'L', 'N', '', '01.07.000005', '06.03.720004', 'E', 'Loan amortization of fees SL (correction of last EOY balances)');
-- HFT
insert into cfe.accounting_event values(66, 1, 'sec_hft', '', 'NOMINAL_BALANCE', 'NOMINAL_BALANCE_P', 'A', '', '', '01.04.000001', '0x.0x.999999', 'R', 'Nominal of bond transaction');
insert into cfe.accounting_event values(67, 1, 'sec_hft', 'NOMINAL_BALANCE_D', 'NOMINAL_BALANCE_DD', '', 'A', 'Y', '', '01.04.000001', '0x.0x.999999', 'P', 'Nominal of bond transaction (correction of previous day balances)');
insert into cfe.accounting_event values(68, 1, 'sec_hft', 'NOMINAL_BALANCE_PP', 'NOMINAL_BALANCE_PP', '', 'A', 'Y', '', '01.04.000001', '0x.0x.999999', 'E', 'Nominal of bond transaction (correction of last EOY balances)');
insert into cfe.accounting_event values(69, 1, 'sec_hft', 'NOMINAL_BALANCE', 'NOMINAL_BALANCE_PP', '', 'A', 'N', '', '01.04.000001', '0x.0x.999999', 'E', 'Nominal of bond transaction(correction of last EOY balances)');
insert into cfe.accounting_event values(70, 1, 'sec_hft', '', 'INTEREST_D', 'INTEREST_DD', 'A', '', '', '06.01.400001', '0x.0x.999999', 'R', 'Coupon payment / Accrual Payment');
insert into cfe.accounting_event values(71, 1, 'sec_hft', 'INTEREST_D', 'INTEREST_DD', '', 'A', 'Y', '', '06.01.400001', '0x.0x.999999', 'P', 'Coupon payment / Accrual Payment (correction of previous day)');
insert into cfe.accounting_event values(72, 1, 'sec_hft', '', 'PREMDISC_D', 'PREMDISC_DD', 'A', '', '', '01.04.100003', '0x.0x.999999', 'R', 'Bond payment of premium / discount');
insert into cfe.accounting_event values(73, 1, 'sec_hft', 'PREMDISC_D', 'PREMDISC_DD', '', 'A', 'Y', '', '01.04.100003', '0x.0x.999999', 'P', 'Bond payment of premium / discount (correction of previous day balances)');
insert into cfe.accounting_event values(74, 1, 'sec_hft', 'PREMDISC_PP', 'PREMDISC_PP', '', 'A', 'Y', '', '01.04.100003', '0x.0x.999999', 'E', 'Bond payment of premium / discount (correction of last EOY balances)');
insert into cfe.accounting_event values(75, 1, 'sec_hft', 'PREMDISC', 'PREMDISC_PP', '', 'A', 'N', '', '01.04.100003', '0x.0x.999999', 'E', 'Bond payment of premium / discount (correction of last EOY balances)');
insert into cfe.accounting_event values(76, 1, 'sec_hft', '', 'FEE_PL_D', 'FEE_PL_DD', 'A', '', '', '06.02.400001', '0x.0x.999999', 'R', 'Bond payment of fee direct P&L (incoming)');
insert into cfe.accounting_event values(77, 1, 'sec_hft', 'FEE_PL_D', 'FEE_PL_DD', '', 'A', 'Y', '', '06.02.400001', '0x.0x.999999', 'R', 'Bond payment of fee direct P&L (incoming)');
insert into cfe.accounting_event values(78, 1, 'sec_hft', '', 'FEE_PL_D', 'FEE_PL_DD', 'L', '', '', '06.04.400001', '0x.0x.999999', 'R', 'Bond payment of fee direct P&L (outgoing)');
insert into cfe.accounting_event values(79, 1, 'sec_hft', 'FEE_PL_D', 'FEE_PL_DD', '', 'L', 'Y', '', '06.04.400001', '0x.0x.999999', 'R', 'Bond payment of fee direct P&L (outgoing)');
insert into cfe.accounting_event values(80, 1, 'sec_hft', '', 'MARKET_PRICE_PORTION', 'MARKET_PRICE_PORTION_P', 'A', '', '', '06.06.400001', '01.04.000007', 'R', 'Value Change due to Market');
insert into cfe.accounting_event values(81, 1, 'sec_hft', 'MARKET_PRICE_PORTION_D', 'MARKET_PRICE_PORTION_DD', '', 'A', 'Y', '', '06.06.400001', '01.04.000007', 'P', 'Value Change due to Market (correction of previous day balances)');
insert into cfe.accounting_event values(82, 1, 'sec_hft', 'MARKET_PRICE_PORTION_PP', 'MARKET_PRICE_PORTION_PP', '', 'A', 'Y', '', '06.06.400001', '01.04.000007', 'E', 'Value Change due to Market (correction of last EOY balances)');
insert into cfe.accounting_event values(83, 1, 'sec_hft', 'MARKET_PRICE_PORTION', 'MARKET_PRICE_PORTION_PP', '', 'A', 'N', '', '06.06.400001', '01.04.000007', 'E', 'Value Change due to Market (correction of last EOY balances)');
insert into cfe.accounting_event values(84, 1, 'sec_hft', '', 'CREDIT_SPREAD_PORTION', 'CREDIT_SPREAD_PORTION_P', 'A', '', '', '06.06.400001', '01.04.000008', 'R', 'Value Change due to Credit');
insert into cfe.accounting_event values(85, 1, 'sec_hft', 'CREDIT_SPREAD_PORTION_D', 'CREDIT_SPREAD_PORTION_DD', '', 'A', 'Y', '', '06.06.400001', '01.04.000008', 'P', 'Value Change due to Credit (correction of previous day balances)');
insert into cfe.accounting_event values(86, 1, 'sec_hft', 'CREDIT_SPREAD_PORTION_PP', 'CREDIT_SPREAD_PORTION_PP', '', 'A', 'Y', '', '06.06.400001', '01.04.000008', 'E', 'Value Change due to Credit (correction of last EOY balances)');
insert into cfe.accounting_event values(87, 1, 'sec_hft', 'CREDIT_SPREAD_PORTION', 'CREDIT_SPREAD_PORTION_PP', '', 'A', 'N', '', '06.06.400001', '01.04.000008', 'E', 'Value Change due to Credit (correction of last EOY balances)');
insert into cfe.accounting_event values(88, 1, 'sec_hft', '', 'TRADE_RESULT', 'TRADE_RESULT_P', 'A', '', '', '06.06.400002', '01.04.100003', 'R', 'Realized P&L');
insert into cfe.accounting_event values(89, 1, 'sec_hft', 'TRADE_RESULT_D', 'TRADE_RESULT_DD', '', 'A', 'Y', '', '06.06.400002', '01.04.100003', 'P', 'Realized P&L (correction of previous day balances)');
insert into cfe.accounting_event values(90, 1, 'sec_hft', 'TRADE_RESULT_PP', 'TRADE_RESULT_PP', '', 'A', 'Y', '', '06.06.400002', '01.04.100003', 'E', 'Realized P&L (correction of last EOY balances)');
insert into cfe.accounting_event values(91, 1, 'sec_hft', 'TRADE_RESULT', 'TRADE_RESULT_PP', '', 'A', 'N', '', '06.06.400002', '01.04.100003', 'E', 'Realized P&L (correction of last EOY balances)');
insert into cfe.accounting_event values(92, 1, 'sec_hft', '', 'ACCRUED_INTEREST', 'ACCRUED_INTEREST_P', 'A', '', '', '01.04.000002', '06.01.400001', 'R', 'Bond accrual of coupon');
insert into cfe.accounting_event values(93, 1, 'sec_hft', 'ACCRUED_INTEREST_D', 'ACCRUED_INTEREST_DD', '', 'A', 'Y', '', '01.04.000002', '06.01.400001', 'P', 'Bond accrual of coupon (correction of previous day income)');
insert into cfe.accounting_event values(94, 1, 'sec_hft', 'ACCRUED_INTEREST_PP', 'ACCRUED_INTEREST_PP', '', 'A', 'Y', '', '01.04.000002', '06.01.400001', 'E', 'Bond accrual of coupon (correction of last EOY balances)');
insert into cfe.accounting_event values(95, 1, 'sec_hft', 'ACCRUED_INTEREST', 'ACCRUED_INTEREST_PP', '', 'A', 'N', '', '01.04.000002', '06.01.400001', 'E', 'Bond accrual of coupon (correction of last EOY balances)');
-- AFS
insert into cfe.accounting_event values(96, 1, 'sec_afs', '', 'NOMINAL_BALANCE', 'NOMINAL_BALANCE_P', 'A', '', '', '01.04.000001', '0x.0x.999999', 'R', 'Nominal of bond transaction');
insert into cfe.accounting_event values(97, 1, 'sec_afs', 'NOMINAL_BALANCE_D', 'NOMINAL_BALANCE_DD', '', 'A', 'Y', '', '01.04.000001', '0x.0x.999999', 'P', 'Nominal of bond transaction (correction of previous day balances)');
insert into cfe.accounting_event values(98, 1, 'sec_afs', 'NOMINAL_BALANCE_PP', 'NOMINAL_BALANCE_PP', '', 'A', 'Y', '', '01.04.000001', '0x.0x.999999', 'E', 'Nominal of bond transaction (correction of last EOY balances)');
insert into cfe.accounting_event values(99, 1, 'sec_afs', 'NOMINAL_BALANCE', 'NOMINAL_BALANCE_PP', '', 'A', 'N', '', '01.04.000001', '0x.0x.999999', 'E', 'Nominal of bond transaction(correction of last EOY balances)');
insert into cfe.accounting_event values(100, 1, 'sec_afs', '', 'INTEREST_D', 'INTEREST_DD', 'A', '', '', '06.01.400001', '0x.0x.999999', 'R', 'Coupon payment / Accrual Payment');
insert into cfe.accounting_event values(101, 1, 'sec_afs', 'INTEREST_D', 'INTEREST_DD', '', 'A', 'Y', '', '06.01.400001', '0x.0x.999999', 'P', 'Coupon payment / Accrual Payment (correction of previous day)');
insert into cfe.accounting_event values(102, 1, 'sec_afs', '', 'PREMDISC_D', 'PREMDISC_DD', 'A', '', '', '06.01.400002', '0x.0x.999999', 'R', 'Bond payment of premium / discount');
insert into cfe.accounting_event values(103, 1, 'sec_afs', 'PREMDISC_D', 'PREMDISC_DD', '', 'A', 'Y', '', '06.01.400002', '0x.0x.999999', 'P', 'Bond payment of premium / discount (correction of previous day balances)');
insert into cfe.accounting_event values(104, 1, 'sec_afs', 'PREMDISC_PP', 'PREMDISC_PP', '', 'A', 'Y', '', '06.01.400002', '0x.0x.999999', 'E', 'Bond payment of premium / discount (correction of last EOY balances)');
insert into cfe.accounting_event values(105, 1, 'sec_afs', 'PREMDISC', 'PREMDISC_PP', '', 'A', 'N', '', '06.01.400002', '0x.0x.999999', 'E', 'Bond payment of premium / discount (correction of last EOY balances)');
insert into cfe.accounting_event values(106, 1, 'sec_afs', '', 'FEE_D', 'FEE_DD', 'A', '', '', '06.01.400003', '0x.0x.999999', 'R', 'Bond payment of fees to be amortized');
insert into cfe.accounting_event values(107, 1, 'sec_afs', 'FEE_D', 'FEE_DD', '', 'A', 'Y', '', '06.01.400003', '0x.0x.999999', 'P', 'Bond payment of fees to be amortized (correction of previous day balances)');
insert into cfe.accounting_event values(108, 1, 'sec_afs', 'FEE_PP', 'FEE_PP', '', 'A', 'Y', '', '06.01.400003', '0x.0x.999999', 'E', 'Bond payment of fees to be amortized (correction of last EOY balances)');
insert into cfe.accounting_event values(109, 1, 'sec_afs', 'FEE', 'FEE_PP', '', 'A', 'N', '', '06.01.400003', '0x.0x.999999', 'E', 'Bond payment of fees to be amortized (correction of last EOY balances)');
insert into cfe.accounting_event values(110, 1, 'sec_afs', '', 'FEE_SL_D', 'FEE_SL_DD', 'A', '', '', '06.01.400004', '0x.0x.999999', 'R', 'Bond payment of fees to be amortized SL');
insert into cfe.accounting_event values(111, 1, 'sec_afs', 'FEE_SL_D', 'FEE_SL_DD', '', 'A', 'Y', '', '06.01.400004', '0x.0x.999999', 'P', 'Bond payment of fees to be amortized SL (correction of previous day balances)');
insert into cfe.accounting_event values(112, 1, 'sec_afs', 'FEE_SL_PP', 'FEE_SL_PP', '', 'A', 'Y', '', '06.01.400004', '0x.0x.999999', 'E', 'Bond payment of fees to be amortized SL (correction of last EOY balances)');
insert into cfe.accounting_event values(113, 1, 'sec_afs', 'FEE_SL', 'FEE_SL_PP', '', 'A', 'N', '', '06.01.400004', '0x.0x.999999', 'E', 'Bond payment of fees to be amortized SL (correction of last EOY balances)');
insert into cfe.accounting_event values(114, 1, 'sec_afs', '', 'FEE_PL_D', 'FEE_PL_DD', 'A', '', '', '06.02.400001', '0x.0x.999999', 'R', 'Bond payment of fee direct P&L (incoming)');
insert into cfe.accounting_event values(115, 1, 'sec_afs', 'FEE_PL_D', 'FEE_PL_DD', '', 'A', 'Y', '', '06.02.400001', '0x.0x.999999', 'R', 'Bond payment of fee direct P&L (incoming)');
insert into cfe.accounting_event values(116, 1, 'sec_afs', '', 'FEE_D', 'FEE_DD', 'L', '', '', '06.03.420003', '0x.0x.999999', 'R', 'Bond payment of fees to be amortized');
insert into cfe.accounting_event values(117, 1, 'sec_afs', 'FEE_D', 'FEE_DD', '', 'L', 'Y', '', '06.03.420003', '0x.0x.999999', 'P', 'Bond payment of fees to be amortized (correction of previous day balances)');
insert into cfe.accounting_event values(118, 1, 'sec_afs', 'FEE_PP', 'FEE_PP', '', 'L', 'Y', '', '06.03.420003', '0x.0x.999999', 'E', 'Bond payment of fees to be amortized (correction of last EOY balances)');
insert into cfe.accounting_event values(119, 1, 'sec_afs', 'FEE', 'FEE_PP', '', 'L', 'N', '', '06.03.420003', '0x.0x.999999', 'E', 'Bond payment of fees to be amortized (correction of last EOY balances)');
insert into cfe.accounting_event values(120, 1, 'sec_afs', '', 'FEE_SL_D', 'FEE_SL_DD', 'L', '', '', '06.03.420004', '0x.0x.999999', 'R', 'Bond payment of fees to be amortized SL');
insert into cfe.accounting_event values(121, 1, 'sec_afs', 'FEE_SL_D', 'FEE_SL_DD', '', 'L', 'Y', '', '06.03.420004', '0x.0x.999999', 'P', 'Bond payment of fees to be amortized SL (correction of previous day balances)');
insert into cfe.accounting_event values(122, 1, 'sec_afs', 'FEE_SL_PP', 'FEE_SL_PP', '', 'L', 'Y', '', '06.03.420004', '0x.0x.999999', 'E', 'Bond payment of fees to be amortized SL (correction of last EOY balances)');
insert into cfe.accounting_event values(123, 1, 'sec_afs', 'FEE_SL', 'FEE_SL_PP', '', 'L', 'N', '', '06.03.420004', '0x.0x.999999', 'E', 'Bond payment of fees to be amortized SL (correction of last EOY balances)');
insert into cfe.accounting_event values(124, 1, 'sec_afs', '', 'FEE_PL_D', 'FEE_PL_DD', 'L', '', '', '06.04.400001', '0x.0x.999999', 'R', 'Bond payment of fee direct P&L (outgoing)');
insert into cfe.accounting_event values(125, 1, 'sec_afs', 'FEE_PL_D', 'FEE_PL_DD', '', 'L', 'Y', '', '06.04.400001', '0x.0x.999999', 'R', 'Bond payment of fee direct P&L (outgoing)');
insert into cfe.accounting_event values(126, 1, 'sec_afs', '', 'ACCRUED_INTEREST', 'ACCRUED_INTEREST_P', 'A', '', '', '01.04.000002', '06.01.400001', 'R', 'Bond accrual of interest');
insert into cfe.accounting_event values(127, 1, 'sec_afs', 'ACCRUED_INTEREST_D', 'ACCRUED_INTEREST_DD', '', 'A', 'Y', '', '01.04.000002', '06.01.400001', 'P', 'Bond accrual of interest (correction of previous day income)');
insert into cfe.accounting_event values(128, 1, 'sec_afs', 'ACCRUED_INTEREST_PP', 'ACCRUED_INTEREST_PP', '', 'A', 'Y', '', '01.04.000002', '06.01.400001', 'E', 'Bond accrual of interest (correction of last EOY balances)');
insert into cfe.accounting_event values(129, 1, 'sec_afs', 'ACCRUED_INTEREST', 'ACCRUED_INTEREST_PP', '', 'A', 'N', '', '01.04.000002', '06.01.400001', 'E', 'Bond accrual of interest (correction of last EOY balances)');
insert into cfe.accounting_event values(130, 1, 'sec_afs', '', 'UNAMORTIZED_FEE', 'UNAMORTIZED_FEE_P', 'A', '', '', '01.04.000004', '06.01.400003', 'R', 'Bond amortization of fees');
insert into cfe.accounting_event values(131, 1, 'sec_afs', 'UNAMORTIZED_FEE_D', 'UNAMORTIZED_FEE_DD', '', 'A', 'Y', '', '01.04.000004', '06.01.400003', 'P', 'Bond amortization of fees (correction of previous day income)');
insert into cfe.accounting_event values(132, 1, 'sec_afs', 'UNAMORTIZED_FEE_PP', 'UNAMORTIZED_FEE_PP', '', 'A', 'Y', '', '01.04.000004', '06.01.400003', 'E', 'Bond amortization of fees (correction of last EOY balances)');
insert into cfe.accounting_event values(133, 1, 'sec_afs', 'UNAMORTIZED_FEE', 'UNAMORTIZED_FEE_PP', '', 'A', 'N', '', '01.04.000004', '06.01.400003', 'E', 'Bond amortization of fees (correction of last EOY balances)');
insert into cfe.accounting_event values(134, 1, 'sec_afs', '', 'UNAMORTIZED_FEE_SL', 'UNAMORTIZED_FEE_SL_P', 'A', '', '', '01.04.000005', '06.01.400004', 'R', 'Bond amortization of fees SL');
insert into cfe.accounting_event values(135, 1, 'sec_afs', 'UNAMORTIZED_FEE_SL_D', 'UNAMORTIZED_FEE_SL_DD', '', 'A', 'Y', '', '01.04.000005', '06.01.400004', 'P', 'Bond amortization of fees SL (correction of previous day income)');
insert into cfe.accounting_event values(136, 1, 'sec_afs', 'UNAMORTIZED_FEE_SL_PP', 'UNAMORTIZED_FEE_SL_PP', '', 'A', 'Y', '', '01.04.000005', '06.01.400004', 'E', 'Bond amortization of fees SL (correction of last EOY balances)');
insert into cfe.accounting_event values(137, 1, 'sec_afs', 'UNAMORTIZED_FEE_SL', 'UNAMORTIZED_FEE_SL_PP', '', 'A', 'N', '', '01.04.000005', '06.01.400004', 'E', 'Bond amortization of fees SL (correction of last EOY balances)');
insert into cfe.accounting_event values(138, 1, 'sec_afs', '', 'INTEREST_SMOOTHING', 'INTEREST_SMOOTHING_P', 'A', '', '', '01.04.000006', '06.01.400005', 'R', 'Bond interest smoothing');
insert into cfe.accounting_event values(139, 1, 'sec_afs', 'INTEREST_SMOOTHING_D', 'INTEREST_SMOOTHING_DD', '', 'A', 'Y', '', '01.04.000006', '06.01.400005', 'P', 'Bond interest smoothing (correction of previous day income)');
insert into cfe.accounting_event values(140, 1, 'sec_afs', 'INTEREST_SMOOTHING_PP', 'INTEREST_SMOOTHING_PP', '', 'A', 'Y', '', '01.04.000006', '06.01.400005', 'E', 'Bond interest smoothing (correction of last EOY balances)');
insert into cfe.accounting_event values(141, 1, 'sec_afs', 'INTEREST_SMOOTHING', 'INTEREST_SMOOTHING_PP', '', 'A', 'N', '', '01.04.000006', '06.01.400005', 'E', 'Bond nterest smoothing (correction of last EOY balances)');
insert into cfe.accounting_event values(142, 1, 'sec_afs', '', 'UNAMORTIZED_FEE', 'UNAMORTIZED_FEE_P', 'L', '', '', '01.04.000004', '06.03.420003', 'R', 'Bond amortization of fees');
insert into cfe.accounting_event values(143, 1, 'sec_afs', 'UNAMORTIZED_FEE_D', 'UNAMORTIZED_FEE_DD', '', 'L', 'Y', '', '01.04.000004', '06.03.420003', 'P', 'Bond amortization of fees (correction of previous day income)');
insert into cfe.accounting_event values(144, 1, 'sec_afs', 'UNAMORTIZED_FEE_PP', 'UNAMORTIZED_FEE_PP', '', 'L', 'Y', '', '01.04.000004', '06.03.420003', 'E', 'Bond amortization of fees (correction of last EOY balances)');
insert into cfe.accounting_event values(145, 1, 'sec_afs', 'UNAMORTIZED_FEE', 'UNAMORTIZED_FEE_PP', '', 'L', 'N', '', '01.04.000004', '06.03.420003', 'E', 'Bond amortization of fees (correction of last EOY balances)');
insert into cfe.accounting_event values(146, 1, 'sec_afs', '', 'UNAMORTIZED_FEE_SL', 'UNAMORTIZED_FEE_SL_P', 'L', '', '', '01.04.000005', '06.03.420004', 'R', 'Bond amortization of fees SL');
insert into cfe.accounting_event values(147, 1, 'sec_afs', 'UNAMORTIZED_FEE_SL_D', 'UNAMORTIZED_FEE_SL_DD', '', 'L', 'Y', '', '01.04.000005', '06.03.420004', 'P', 'Bond amortization of fees SL (correction of previous day income)');
insert into cfe.accounting_event values(148, 1, 'sec_afs', 'UNAMORTIZED_FEE_SL_PP', 'UNAMORTIZED_FEE_SL_PP', '', 'L', 'Y', '', '01.04.000005', '06.03.420004', 'E', 'Bond amortization of fees SL (correction of last EOY balances)');
insert into cfe.accounting_event values(149, 1, 'sec_afs', 'UNAMORTIZED_FEE_SL', 'UNAMORTIZED_FEE_SL_PP', '', 'L', 'N', '', '01.04.000005', '06.03.420004', 'E', 'Bond amortization of fees SL (correction of last EOY balances)');
insert into cfe.accounting_event values(150, 1, 'sec_afs', '', 'TRADE_RESULT', 'TRADE_RESULT_P', 'A', '', '', '06.06.400002', '0x.0x.999999', 'R', 'Realized P&L');
insert into cfe.accounting_event values(151, 1, 'sec_afs', 'TRADE_RESULT_D', 'TRADE_RESULT_DD', '', 'A', 'Y', '', '06.06.400002', '0x.0x.999999', 'P', 'Realized P&L (correction of previous day balances)');
insert into cfe.accounting_event values(152, 1, 'sec_afs', 'TRADE_RESULT_PP', 'TRADE_RESULT_PP', '', 'A', 'Y', '', '06.06.400002', '0x.0x.999999', 'E', 'Realized P&L (correction of last EOY balances)');
insert into cfe.accounting_event values(153, 1, 'sec_afs', 'TRADE_RESULT', 'TRADE_RESULT_PP', '', 'A', 'N', '', '06.06.400002', '0x.0x.999999', 'E', 'Realized P&L (correction of last EOY balances)');
insert into cfe.accounting_event values(154, 1, 'sec_afs', '', 'UNAMORTIZED_PREMDISC', 'UNAMORTIZED_PREMDISC_P', 'A', '', '', '01.04.000003', '06.01.400002', 'R', 'Bond amortization of discount');
insert into cfe.accounting_event values(155, 1, 'sec_afs', 'UNAMORTIZED_PREMDISC_D', 'UNAMORTIZED_PREMDISC_DD', '', 'A', 'Y', '', '01.04.000003', '06.01.400002', 'P', 'Bond amortization of discount (correction of previous day income)');
insert into cfe.accounting_event values(156, 1, 'sec_afs', 'UNAMORTIZED_PREMDISC_PP', 'UNAMORTIZED_PREMDISC_PP', '', 'A', 'Y', '', '01.04.000003', '06.01.400002', 'E', 'Bond amortization of discount (correction of last EOY balances)');
insert into cfe.accounting_event values(157, 1, 'sec_afs', 'UNAMORTIZED_PREMDISC', 'UNAMORTIZED_PREMDISC_PP', '', 'A', 'N', '', '01.04.000003', '06.01.400002', 'E', 'Bond amortization of discount (correction of last EOY balances)');
insert into cfe.accounting_event values(158, 1, 'sec_afs', '', 'UNAMORTIZED_PREMDISC', 'UNAMORTIZED_PREMDISC_P', 'L', '', '', '01.04.000003', '06.03.420002', 'R', 'Bond amortization of discount');
insert into cfe.accounting_event values(159, 1, 'sec_afs', 'UNAMORTIZED_PREMDISC_D', 'UNAMORTIZED_PREMDISC_DD', '', 'L', 'Y', '', '01.04.000003', '06.03.420002', 'P', 'Bond amortization of discount (correction of previous day income)');
insert into cfe.accounting_event values(160, 1, 'sec_afs', 'UNAMORTIZED_PREMDISC_PP', 'UNAMORTIZED_PREMDISC_PP', '', 'L', 'Y', '', '01.04.000003', '06.03.420002', 'E', 'Bond amortization of discount (correction of last EOY balances)');
insert into cfe.accounting_event values(161, 1, 'sec_afs', 'UNAMORTIZED_PREMDISC', 'UNAMORTIZED_PREMDISC_PP', '', 'L', 'N', '', '01.04.000003', '06.03.420002', 'E', 'Bond amortization of discount (correction of last EOY balances)');
insert into cfe.accounting_event values(162, 1, 'sec_afs', '', 'MARKET_PRICE_PORTION', 'MARKET_PRICE_PORTION_P', 'A', '', '', '02.06.000002', '01.04.000007', 'R', 'Value Change due to Market');
insert into cfe.accounting_event values(163, 1, 'sec_afs', 'MARKET_PRICE_PORTION_D', 'MARKET_PRICE_PORTION_DD', '', 'A', 'Y', '', '02.06.000002', '01.04.000007', 'P', 'Value Change due to Market (correction of previous day balances)');
insert into cfe.accounting_event values(164, 1, 'sec_afs', 'MARKET_PRICE_PORTION_PP', 'MARKET_PRICE_PORTION_PP', '', 'A', 'Y', '', '02.06.000002', '01.04.000007', 'E', 'Value Change due to Market (correction of last EOY balances)');
insert into cfe.accounting_event values(165, 1, 'sec_afs', 'MARKET_PRICE_PORTION', 'MARKET_PRICE_PORTION_PP', '', 'A', 'N', '', '02.06.000002', '01.04.000007', 'E', 'Value Change due to Market (correction of last EOY balances)');
insert into cfe.accounting_event values(166, 1, 'sec_afs', '', 'CREDIT_SPREAD_PORTION', 'CREDIT_SPREAD_PORTION_P', 'A', '', '', '02.06.000002', '01.04.000008', 'R', 'Value Change due to Credit');
insert into cfe.accounting_event values(167, 1, 'sec_afs', 'CREDIT_SPREAD_PORTION_D', 'CREDIT_SPREAD_PORTION_DD', '', 'A', 'Y', '', '02.06.000002', '01.04.000008', 'P', 'Value Change due to Credit (correction of previous day balances)');
insert into cfe.accounting_event values(168, 1, 'sec_afs', 'CREDIT_SPREAD_PORTION_PP', 'CREDIT_SPREAD_PORTION_PP', '', 'A', 'Y', '', '02.06.000002', '01.04.000008', 'E', 'Value Change due to Credit (correction of last EOY balances)');
insert into cfe.accounting_event values(169, 1, 'sec_afs', 'CREDIT_SPREAD_PORTION', 'CREDIT_SPREAD_PORTION_PP', '', 'A', 'N', '', '02.06.000002', '01.04.000008', 'E', 'Value Change due to Credit (correction of last EOY balances)');
--HTM
insert into cfe.accounting_event values(170, 1, 'sec_htm', '', 'NOMINAL_BALANCE', 'NOMINAL_BALANCE_P', 'A', '', '', '01.04.000001', '0x.0x.999999', 'R', 'Nominal of bond transaction');
insert into cfe.accounting_event values(171, 1, 'sec_htm', 'NOMINAL_BALANCE_D', 'NOMINAL_BALANCE_DD', '', 'A', 'Y', '', '01.04.000001', '0x.0x.999999', 'P', 'Nominal of bond transaction (correction of previous day balances)');
insert into cfe.accounting_event values(172, 1, 'sec_htm', 'NOMINAL_BALANCE_PP', 'NOMINAL_BALANCE_PP', '', 'A', 'Y', '', '01.04.000001', '0x.0x.999999', 'E', 'Nominal of bond transaction (correction of last EOY balances)');
insert into cfe.accounting_event values(173, 1, 'sec_htm', 'NOMINAL_BALANCE', 'NOMINAL_BALANCE_PP', '', 'A', 'N', '', '01.04.000001', '0x.0x.999999', 'E', 'Nominal of bond transaction(correction of last EOY balances)');
insert into cfe.accounting_event values(174, 1, 'sec_htm', '', 'INTEREST_D', 'INTEREST_DD', 'A', '', '', '06.01.400001', '0x.0x.999999', 'R', 'Coupon payment / Accrual Payment');
insert into cfe.accounting_event values(175, 1, 'sec_htm', 'INTEREST_D', 'INTEREST_DD', '', 'A', 'Y', '', '06.01.400001', '0x.0x.999999', 'P', 'Coupon payment / Accrual Payment (correction of previous day)');
insert into cfe.accounting_event values(176, 1, 'sec_htm', '', 'PREMDISC_D', 'PREMDISC_DD', 'A', '', '', '06.01.400002', '0x.0x.999999', 'R', 'Bond payment of premium / discount');
insert into cfe.accounting_event values(177, 1, 'sec_htm', 'PREMDISC_D', 'PREMDISC_DD', '', 'A', 'Y', '', '06.01.400002', '0x.0x.999999', 'P', 'Bond payment of premium / discount (correction of previous day balances)');
insert into cfe.accounting_event values(178, 1, 'sec_htm', 'PREMDISC_PP', 'PREMDISC_PP', '', 'A', 'Y', '', '06.01.400002', '0x.0x.999999', 'E', 'Bond payment of premium / discount (correction of last EOY balances)');
insert into cfe.accounting_event values(179, 1, 'sec_htm', 'PREMDISC', 'PREMDISC_PP', '', 'A', 'N', '', '06.01.400002', '0x.0x.999999', 'E', 'Bond payment of premium / discount (correction of last EOY balances)');
insert into cfe.accounting_event values(180, 1, 'sec_htm', '', 'FEE_D', 'FEE_DD', 'A', '', '', '06.01.400003', '0x.0x.999999', 'R', 'Bond payment of fees to be amortized');
insert into cfe.accounting_event values(181, 1, 'sec_htm', 'FEE_D', 'FEE_DD', '', 'A', 'Y', '', '06.01.400003', '0x.0x.999999', 'P', 'Bond payment of fees to be amortized (correction of previous day balances)');
insert into cfe.accounting_event values(182, 1, 'sec_htm', 'FEE_PP', 'FEE_PP', '', 'A', 'Y', '', '06.01.400003', '0x.0x.999999', 'E', 'Bond payment of fees to be amortized (correction of last EOY balances)');
insert into cfe.accounting_event values(183, 1, 'sec_htm', 'FEE', 'FEE_PP', '', 'A', 'N', '', '06.01.400003', '0x.0x.999999', 'E', 'Bond payment of fees to be amortized (correction of last EOY balances)');
insert into cfe.accounting_event values(184, 1, 'sec_htm', '', 'FEE_SL_D', 'FEE_SL_DD', 'A', '', '', '06.01.400004', '0x.0x.999999', 'R', 'Bond payment of fees to be amortized SL');
insert into cfe.accounting_event values(185, 1, 'sec_htm', 'FEE_SL_D', 'FEE_SL_DD', '', 'A', 'Y', '', '06.01.400004', '0x.0x.999999', 'P', 'Bond payment of fees to be amortized SL (correction of previous day balances)');
insert into cfe.accounting_event values(186, 1, 'sec_htm', 'FEE_SL_PP', 'FEE_SL_PP', '', 'A', 'Y', '', '06.01.400004', '0x.0x.999999', 'E', 'Bond payment of fees to be amortized SL (correction of last EOY balances)');
insert into cfe.accounting_event values(187, 1, 'sec_htm', 'FEE_SL', 'FEE_SL_PP', '', 'A', 'N', '', '06.01.400004', '0x.0x.999999', 'E', 'Bond payment of fees to be amortized SL (correction of last EOY balances)');
insert into cfe.accounting_event values(188, 1, 'sec_htm', '', 'FEE_PL_D', 'FEE_PL_DD', 'A', '', '', '06.02.400001', '0x.0x.999999', 'R', 'Bond payment of fee direct P&L (incoming)');
insert into cfe.accounting_event values(189, 1, 'sec_htm', 'FEE_PL_D', 'FEE_PL_DD', '', 'A', 'Y', '', '06.02.400001', '0x.0x.999999', 'R', 'Bond payment of fee direct P&L (incoming)');
insert into cfe.accounting_event values(190, 1, 'sec_htm', '', 'FEE_D', 'FEE_DD', 'L', '', '', '06.03.420003', '0x.0x.999999', 'R', 'Bond payment of fees to be amortized');
insert into cfe.accounting_event values(191, 1, 'sec_htm', 'FEE_D', 'FEE_DD', '', 'L', 'Y', '', '06.03.420003', '0x.0x.999999', 'P', 'Bond payment of fees to be amortized (correction of previous day balances)');
insert into cfe.accounting_event values(192, 1, 'sec_htm', 'FEE_PP', 'FEE_PP', '', 'L', 'Y', '', '06.03.420003', '0x.0x.999999', 'E', 'Bond payment of fees to be amortized (correction of last EOY balances)');
insert into cfe.accounting_event values(193, 1, 'sec_htm', 'FEE', 'FEE_PP', '', 'L', 'N', '', '06.03.420003', '0x.0x.999999', 'E', 'Bond payment of fees to be amortized (correction of last EOY balances)');
insert into cfe.accounting_event values(194, 1, 'sec_htm', '', 'FEE_SL_D', 'FEE_SL_DD', 'L', '', '', '06.03.420004', '0x.0x.999999', 'R', 'Bond payment of fees to be amortized SL');
insert into cfe.accounting_event values(195, 1, 'sec_htm', 'FEE_SL_D', 'FEE_SL_DD', '', 'L', 'Y', '', '06.03.420004', '0x.0x.999999', 'P', 'Bond payment of fees to be amortized SL (correction of previous day balances)');
insert into cfe.accounting_event values(196, 1, 'sec_htm', 'FEE_SL_PP', 'FEE_SL_PP', '', 'L', 'Y', '', '06.03.420004', '0x.0x.999999', 'E', 'Bond payment of fees to be amortized SL (correction of last EOY balances)');
insert into cfe.accounting_event values(197, 1, 'sec_htm', 'FEE_SL', 'FEE_SL_PP', '', 'L', 'N', '', '06.03.420004', '0x.0x.999999', 'E', 'Bond payment of fees to be amortized SL (correction of last EOY balances)');
insert into cfe.accounting_event values(198, 1, 'sec_htm', '', 'FEE_PL_D', 'FEE_PL_DD', 'L', '', '', '06.04.400001', '0x.0x.999999', 'R', 'Bond payment of fee direct P&L (outgoing)');
insert into cfe.accounting_event values(199, 1, 'sec_htm', 'FEE_PL_D', 'FEE_PL_DD', '', 'L', 'Y', '', '06.04.400001', '0x.0x.999999', 'R', 'Bond payment of fee direct P&L (outgoing)');
insert into cfe.accounting_event values(200, 1, 'sec_htm', '', 'PENALTY_INTEREST_D', 'PENALTY_INTEREST_DD', 'A', '', '', '06.01.700013', '0x.0x.999999', 'R', 'Bond payment of interest');
insert into cfe.accounting_event values(201, 1, 'sec_htm', 'PENALTY_INTEREST_D', 'PENALTY_INTEREST_DD', '', 'A', 'Y', '', '06.01.700013', '0x.0x.999999', 'P', 'Bond payment of interest (correction of previous day income)');
insert into cfe.accounting_event values(202, 1, 'sec_htm', '', 'RECOVERY_BALANCE', 'RECOVERY_BALANCE_P', 'A', '', '', '01.07.000001', '0x.0x.999999', 'R', 'Bond payment of actual recovery in impairment');
insert into cfe.accounting_event values(203, 1, 'sec_htm', 'RECOVERY_BALANCE_D', 'RECOVERY_BALANCE_DD', '', 'A', 'Y', '', '01.07.000001', '0x.0x.999999', 'P', 'Bond payment of actual recovery (correction of previous day balances)');
insert into cfe.accounting_event values(204, 1, 'sec_htm', 'RECOVERY_BALANCE_PP', 'RECOVERY_BALANCE_PP', '', 'A', 'Y', '', '01.07.000001', '0x.0x.999999', 'E', 'Bond payment of actual recovery (correction of last EOY balances)');
insert into cfe.accounting_event values(205, 1, 'sec_htm', 'RECOVERY_BALANCE', 'RECOVERY_BALANCE_PP', '', 'A', 'N', '', '01.07.000001', '0x.0x.999999', 'E', 'Bond payment of actual recovery (correction of last EOY balances)');
insert into cfe.accounting_event values(206, 1, 'sec_htm', '', 'WRITE_DOWN', 'WRITE_DOWN_P', 'A', '', '', '01.07.000001', '06.05.000001', 'R', 'Bond partial write down in impairment');
insert into cfe.accounting_event values(207, 1, 'sec_htm', 'WRITE_DOWN_D', 'WRITE_DOWN_DD', '', 'A', 'Y', '', '01.07.000001', '06.05.000001', 'P', 'Bond partial write down (correction of previous day balances)');
insert into cfe.accounting_event values(208, 1, 'sec_htm', 'WRITE_DOWN_PP', 'WRITE_DOWN_PP', '', 'A', 'Y', '', '01.07.000001', '06.05.000001', 'E', 'Bond partial write down (correction of last EOY balances)');
insert into cfe.accounting_event values(209, 1, 'sec_htm', 'WRITE_DOWN', 'WRITE_DOWN_PP', '', 'A', 'N', '', '01.07.000001', '06.05.000001', 'E', 'Bond partial write down (correction of last EOY balances)');
insert into cfe.accounting_event values(210, 1, 'sec_htm', '', 'UNWINDING', 'UNWINDING_P', 'A', '', '', '06.01.700007', '01.07.000011', 'R', 'Bond unwinding income (impairment)');
insert into cfe.accounting_event values(211, 1, 'sec_htm', 'UNWINDING', 'UNWINDING_P', '', 'A', 'Y', '', '06.01.700007', '01.07.000011', 'P', 'Bond unwinding income (impairment) (correction of previous day income)');
insert into cfe.accounting_event values(212, 1, 'sec_htm', '', 'IMPAIRMENT', 'IMPAIRMENT_P', 'A', '', '', '06.05.000001', '01.07.000011', 'R', 'Bond unwinding income (impairment)');
insert into cfe.accounting_event values(213, 1, 'sec_htm', 'IMPAIRMENT', 'IMPAIRMENT_P', '', 'A', 'Y', '', '06.05.000001', '01.07.000011', 'P', 'Bond unwinding income (impairment) (correction of previous day income)');
--insert into cfe.accounting_event values(214, 1, 'sec_htm', 'D/C entry to set all BS accounts of 0 against Impairment Expense (P&L)', '', '', '', '', '', '06.01.400001', '', '', '');
insert into cfe.accounting_event values(215, 1, 'sec_htm', '', 'ACCRUED_INTEREST', 'ACCRUED_INTEREST_P', 'A', '', '', '01.04.000002', '06.01.400001', 'R', 'Bond accrual of interest');
insert into cfe.accounting_event values(216, 1, 'sec_htm', 'ACCRUED_INTEREST_D', 'ACCRUED_INTEREST_DD', '', 'A', 'Y', '', '01.04.000002', '06.01.400001', 'P', 'Bond accrual of interest (correction of previous day income)');
insert into cfe.accounting_event values(217, 1, 'sec_htm', 'ACCRUED_INTEREST_PP', 'ACCRUED_INTEREST_PP', '', 'A', 'Y', '', '01.04.000002', '06.01.400001', 'E', 'Bond accrual of interest (correction of last EOY balances)');
insert into cfe.accounting_event values(218, 1, 'sec_htm', 'ACCRUED_INTEREST', 'ACCRUED_INTEREST_PP', '', 'A', 'N', '', '01.04.000002', '06.01.400001', 'E', 'Bond accrual of interest (correction of last EOY balances)');
insert into cfe.accounting_event values(219, 1, 'sec_htm', '', 'UNAMORTIZED_FEE', 'UNAMORTIZED_FEE_P', 'A', '', '', '01.04.000004', '06.01.400003', 'R', 'Bond amortization of fees');
insert into cfe.accounting_event values(220, 1, 'sec_htm', 'UNAMORTIZED_FEE_D', 'UNAMORTIZED_FEE_DD', '', 'A', 'Y', '', '01.04.000004', '06.01.400003', 'P', 'Bond amortization of fees (correction of previous day income)');
insert into cfe.accounting_event values(221, 1, 'sec_htm', 'UNAMORTIZED_FEE_PP', 'UNAMORTIZED_FEE_PP', '', 'A', 'Y', '', '01.04.000004', '06.01.400003', 'E', 'Bond amortization of fees (correction of last EOY balances)');
insert into cfe.accounting_event values(222, 1, 'sec_htm', 'UNAMORTIZED_FEE', 'UNAMORTIZED_FEE_PP', '', 'A', 'N', '', '01.04.000004', '06.01.400003', 'E', 'Bond amortization of fees (correction of last EOY balances)');
insert into cfe.accounting_event values(223, 1, 'sec_htm', '', 'UNAMORTIZED_FEE_SL', 'UNAMORTIZED_FEE_SL_P', 'A', '', '', '01.04.000005', '06.01.400004', 'R', 'Bond amortization of fees SL');
insert into cfe.accounting_event values(224, 1, 'sec_htm', 'UNAMORTIZED_FEE_SL_D', 'UNAMORTIZED_FEE_SL_DD', '', 'A', 'Y', '', '01.04.000005', '06.01.400004', 'P', 'Bond amortization of fees SL (correction of previous day income)');
insert into cfe.accounting_event values(225, 1, 'sec_htm', 'UNAMORTIZED_FEE_SL_PP', 'UNAMORTIZED_FEE_SL_PP', '', 'A', 'Y', '', '01.04.000005', '06.01.400004', 'E', 'Bond amortization of fees SL (correction of last EOY balances)');
insert into cfe.accounting_event values(226, 1, 'sec_htm', 'UNAMORTIZED_FEE_SL', 'UNAMORTIZED_FEE_SL_PP', '', 'A', 'N', '', '01.04.000005', '06.01.400004', 'E', 'Bond amortization of fees SL (correction of last EOY balances)');
insert into cfe.accounting_event values(227, 1, 'sec_htm', '', 'INTEREST_SMOOTHING', 'INTEREST_SMOOTHING_P', 'A', '', '', '01.04.000006', '06.01.400005', 'R', 'Bond interest smoothing');
insert into cfe.accounting_event values(228, 1, 'sec_htm', 'INTEREST_SMOOTHING_D', 'INTEREST_SMOOTHING_DD', '', 'A', 'Y', '', '01.04.000006', '06.01.400005', 'P', 'Bond interest smoothing (correction of previous day income)');
insert into cfe.accounting_event values(229, 1, 'sec_htm', 'INTEREST_SMOOTHING_PP', 'INTEREST_SMOOTHING_PP', '', 'A', 'Y', '', '01.04.000006', '06.01.400005', 'E', 'Bond interest smoothing (correction of last EOY balances)');
insert into cfe.accounting_event values(230, 1, 'sec_htm', 'INTEREST_SMOOTHING', 'INTEREST_SMOOTHING_PP', '', 'A', 'N', '', '01.04.000006', '06.01.400005', 'E', 'Bond nterest smoothing (correction of last EOY balances)');
insert into cfe.accounting_event values(231, 1, 'sec_htm', '', 'UNAMORTIZED_FEE', 'UNAMORTIZED_FEE_P', 'L', '', '', '01.04.000004', '06.03.420003', 'R', 'Bond amortization of fees');
insert into cfe.accounting_event values(232, 1, 'sec_htm', 'UNAMORTIZED_FEE_D', 'UNAMORTIZED_FEE_DD', '', 'L', 'Y', '', '01.04.000004', '06.03.420003', 'P', 'Bond amortization of fees (correction of previous day income)');
insert into cfe.accounting_event values(233, 1, 'sec_htm', 'UNAMORTIZED_FEE_PP', 'UNAMORTIZED_FEE_PP', '', 'L', 'Y', '', '01.04.000004', '06.03.420003', 'E', 'Bond amortization of fees (correction of last EOY balances)');
insert into cfe.accounting_event values(234, 1, 'sec_htm', 'UNAMORTIZED_FEE', 'UNAMORTIZED_FEE_PP', '', 'L', 'N', '', '01.04.000004', '06.03.420003', 'E', 'Bond amortization of fees (correction of last EOY balances)');
insert into cfe.accounting_event values(235, 1, 'sec_htm', '', 'UNAMORTIZED_FEE_SL', 'UNAMORTIZED_FEE_SL_P', 'L', '', '', '01.04.000005', '06.03.420004', 'R', 'Bond amortization of fees SL');
insert into cfe.accounting_event values(236, 1, 'sec_htm', 'UNAMORTIZED_FEE_SL_D', 'UNAMORTIZED_FEE_SL_DD', '', 'L', 'Y', '', '01.04.000005', '06.03.420004', 'P', 'Bond amortization of fees SL (correction of previous day income)');
insert into cfe.accounting_event values(237, 1, 'sec_htm', 'UNAMORTIZED_FEE_SL_PP', 'UNAMORTIZED_FEE_SL_PP', '', 'L', 'Y', '', '01.04.000005', '06.03.420004', 'E', 'Bond amortization of fees SL (correction of last EOY balances)');
insert into cfe.accounting_event values(238, 1, 'sec_htm', 'UNAMORTIZED_FEE_SL', 'UNAMORTIZED_FEE_SL_PP', '', 'L', 'N', '', '01.04.000005', '06.03.420004', 'E', 'Bond amortization of fees SL (correction of last EOY balances)');
insert into cfe.accounting_event values(239, 1, 'sec_htm', '', 'TRADE_RESULT', 'TRADE_RESULT_P', 'A', '', '', '06.06.400002', '0x.0x.999999', 'R', 'Realized P&L');
insert into cfe.accounting_event values(240, 1, 'sec_htm', 'TRADE_RESULT_D', 'TRADE_RESULT_DD', '', 'A', 'Y', '', '06.06.400002', '0x.0x.999999', 'P', 'Realized P&L (correction of previous day balances)');
insert into cfe.accounting_event values(241, 1, 'sec_htm', 'TRADE_RESULT_PP', 'TRADE_RESULT_PP', '', 'A', 'Y', '', '06.06.400002', '0x.0x.999999', 'E', 'Realized P&L (correction of last EOY balances)');
insert into cfe.accounting_event values(242, 1, 'sec_htm', 'TRADE_RESULT', 'TRADE_RESULT_PP', '', 'A', 'N', '', '06.06.400002', '0x.0x.999999', 'E', 'Realized P&L (correction of last EOY balances)');
insert into cfe.accounting_event values(243, 1, 'sec_htm', '', 'UNAMORTIZED_PREMDISC', 'UNAMORTIZED_PREMDISC_P', 'A', '', '', '01.04.000003', '06.01.400002', 'R', 'Bond amortization of discount');
insert into cfe.accounting_event values(244, 1, 'sec_htm', 'UNAMORTIZED_PREMDISC_D', 'UNAMORTIZED_PREMDISC_DD', '', 'A', 'Y', '', '01.04.000003', '06.01.400002', 'P', 'Bond amortization of discount (correction of previous day income)');
insert into cfe.accounting_event values(245, 1, 'sec_htm', 'UNAMORTIZED_PREMDISC_PP', 'UNAMORTIZED_PREMDISC_PP', '', 'A', 'Y', '', '01.04.000003', '06.01.400002', 'E', 'Bond amortization of discount (correction of last EOY balances)');
insert into cfe.accounting_event values(246, 1, 'sec_htm', 'UNAMORTIZED_PREMDISC', 'UNAMORTIZED_PREMDISC_PP', '', 'A', 'N', '', '01.04.000003', '06.01.400002', 'E', 'Bond amortization of discount (correction of last EOY balances)');
insert into cfe.accounting_event values(247, 1, 'sec_htm', '', 'UNAMORTIZED_PREMDISC', 'UNAMORTIZED_PREMDISC_P', 'L', '', '', '01.04.000003', '06.03.420002', 'R', 'Bond amortization of discount');
insert into cfe.accounting_event values(248, 1, 'sec_htm', 'UNAMORTIZED_PREMDISC_D', 'UNAMORTIZED_PREMDISC_DD', '', 'L', 'Y', '', '01.04.000003', '06.03.420002', 'P', 'Bond amortization of discount (correction of previous day income)');
insert into cfe.accounting_event values(249, 1, 'sec_htm', 'UNAMORTIZED_PREMDISC_PP', 'UNAMORTIZED_PREMDISC_PP', '', 'L', 'Y', '', '01.04.000003', '06.03.420002', 'E', 'Bond amortization of discount (correction of last EOY balances)');
insert into cfe.accounting_event values(250, 1, 'sec_htm', 'UNAMORTIZED_PREMDISC', 'UNAMORTIZED_PREMDISC_PP', '', 'L', 'N', '', '01.04.000003', '06.03.420002', 'E', 'Bond amortization of discount (correction of last EOY balances)');




CREATE SEQUENCE cfe.id_account_seq;
CREATE TABLE cfe.ledger_account
  (
     id_account    INTEGER PRIMARY KEY NOT NULL
     , code        VARCHAR(40) NOT NULL
     , id_currency VARCHAR(3) NOT NULL
     , id_fee_type   VARCHAR(12)
     , description VARCHAR(255)
     , start_date  DATE NOT NULL
     , end_date    DATE
  );

CREATE TABLE cfe.ledger_account_balance
  (
     id_account          INTEGER NOT NULL
     , value_date        DATE NOT NULL
     , posting_timestamp TIMESTAMP NOT NULL
     , balance           DECIMAL(23, 5) NOT NULL
     , balance_bc        DECIMAL(23, 5) NOT NULL
  );

CREATE UNIQUE INDEX cfe.ledger_account_balance_idx1
  ON cfe.ledger_account_balance(id_account, value_date, posting_timestamp);

CREATE TABLE cfe.ledger_account_entry
  (
     id_account_credit     INTEGER NOT NULL
     , id_account_debit    INTEGER NOT NULL
     , id_instrument       VARCHAR(40) NOT NULL
     , id_accounting_event SMALLINT NOT NULL
     , value_date          DATE NOT NULL
     , posting_date		   DATE NOT NULL
     , amount              DECIMAL(23, 5) NOT NULL
     , amount_bc           DECIMAL(23, 5) NOT NULL
  );

CREATE INDEX cfe.ledger_account_entry_idx1
  ON cfe.ledger_account_entry(id_account_credit, value_date, posting_date);

CREATE INDEX cfe.ledger_account_entry_idx2
  ON cfe.ledger_account_entry(id_account_debit, value_date, posting_date);

CREATE INDEX cfe.ledger_account_entry_idx3
  ON cfe.ledger_account_entry(id_instrument, value_date, posting_date);

---------------------------------------------------------------------------------------------------------------
UPDATE cfe.version_info
SET    installation_end = SYSDATE
WHERE  major_version = 0
       AND minor_version = 0
       AND patch_level = 1;

--
-- fill the chart of account
insert into cfe.fee_type VALUES ('A', 'A-Fee');
insert into cfe.fee_type VALUES ('K', 'K-Fee');
insert into cfe.fee_type VALUES ('SEC_PREM', 'Premium');
insert into cfe.fee_type VALUES ('SEC_DISC', 'Discount');
insert into cfe.ledger_account
select
	cfe.id_account_seq.nextval
	, code
	, id_currency
	, null
	, null
	, current_date
	, null
from (
	select distinct code_credit_account code from cfe.accounting_event
	union select distinct code_debit_account from cfe.accounting_event
) t1
	join cfe.currency
;
insert into cfe.ledger_account
select
	cfe.id_account_seq.nextval
	, code
	, id_currency
	, id_fee_type
	, null
	, current_date
	, null
from (
	select distinct code_credit_account code from cfe.accounting_event
	union select distinct code_debit_account from cfe.accounting_event
) t1
	join cfe.currency
	join cfe.fee_type
;

update cfe.ledger_account set description='Asset' where code='01.';
update cfe.ledger_account set description='Cash and equivalent' where code='01.01.';
update cfe.ledger_account set description='Cash and equivalent' where code='01.01.000001';
update cfe.ledger_account set description='Settlement Account' where code='0x.0x.999999';
update cfe.ledger_account set description='Current account (CURACC) assets' where code='01.02.';
update cfe.ledger_account set description='CURACC A Daily Payable Assets' where code='01.02.000001';
update cfe.ledger_account set description='CURACC A Interest Accrual/Deferral Receivable' where code='01.02.000002';
update cfe.ledger_account set description='CURACC A Fees Accrual/Deferral' where code='01.02.000005';
update cfe.ledger_account set description='CURACC A Overdue Assets' where code='01.02.000010';
update cfe.ledger_account set description='CURACC A Risk Provisioning' where code='01.02.000011';
update cfe.ledger_account set description='MM and deposit assets' where code='01.03.';
update cfe.ledger_account set description='MM A Nominal' where code='01.03.000001';
update cfe.ledger_account set description='MM A Interest Accrual/Deferral' where code='01.03.000002';
update cfe.ledger_account set description='MM A Premium/Discount' where code='01.03.000003';
update cfe.ledger_account set description='MM A Transaction Cost' where code='01.03.000004';
update cfe.ledger_account set description='MM A Fees Accrual/Deferral' where code='01.03.000005';
update cfe.ledger_account set description='MM A Interest Smoothing Effect' where code='01.03.000006';
update cfe.ledger_account set description='MM A Value Changes Market Price' where code='01.03.000007';
update cfe.ledger_account set description='MM A Value Changes Credit Spread' where code='01.03.000008';
update cfe.ledger_account set description='BOND Securities' where code='01.04.';
update cfe.ledger_account set description='BOND Nominal' where code='01.04.000001';
update cfe.ledger_account set description='BOND Interest Accrual/Deferral' where code='01.04.000002';
update cfe.ledger_account set description='BOND Premium/Discount' where code='01.04.000003';
update cfe.ledger_account set description='BOND Trading Position' where code='01.04.100003';
update cfe.ledger_account set description='BOND Transaction Cost' where code='01.04.000004';
update cfe.ledger_account set description='BOND Interest Smoothing Effect' where code='01.04.000006';
update cfe.ledger_account set description='BOND Value Changes Market Price' where code='01.04.000007';
update cfe.ledger_account set description='BOND Value Changes Credit Spread' where code='01.04.000008';
update cfe.ledger_account set description='REPO Assets' where code='01.05.';
update cfe.ledger_account set description='REPO A Nominal' where code='01.05.000001';
update cfe.ledger_account set description='REPO A Interest Accrual/Deferral' where code='01.05.000002';
update cfe.ledger_account set description='REPO A Premium/Discount' where code='01.05.000003';
update cfe.ledger_account set description='Loans (LN)' where code='01.07.';
update cfe.ledger_account set description='LN Nominal' where code='01.07.000001';
update cfe.ledger_account set description='LN Interest Accrual/Deferral' where code='01.07.000002';
update cfe.ledger_account set description='LN Premium/Discount' where code='01.07.000003';
update cfe.ledger_account set description='LN Transaction Cost' where code='01.07.000004';
update cfe.ledger_account set description='LN Fees Accrual/Deferral' where code='01.07.000005';
update cfe.ledger_account set description='LN Interest Smoothing' where code='01.07.000006';
update cfe.ledger_account set description='LN Value Changes Market Price' where code='01.07.000007';
update cfe.ledger_account set description='LN Value Changes Credit Spread' where code='01.07.000008';
update cfe.ledger_account set description='LN BMR Discount' where code='01.07.000009';
update cfe.ledger_account set description='LN Overdue Assets' where code='01.07.000010';
update cfe.ledger_account set description='LN Risk Provisioning' where code='01.07.000011';
update cfe.ledger_account set description='PORTFOLIO Risk Provisioning' where code='01.07.000012';
update cfe.ledger_account set description='LN Penalty Interest' where code='01.07.000013';
update cfe.ledger_account set description='DERIVATIVE assets' where code='01.08.';
update cfe.ledger_account set description='DERIVATIVES A Account' where code='01.08.000001';
update cfe.ledger_account set description='DERIVATIVES A Interest Accrual/Deferral' where code='01.08.000002';
update cfe.ledger_account set description='DERIVATIVES A Charges Accrual/Deferral' where code='01.08.000005';
update cfe.ledger_account set description='DERIVATIVES A Valuation' where code='01.08.000007';
update cfe.ledger_account set description='Other financial assets' where code='01.09.';
update cfe.ledger_account set description='OFF-BALANCE SHEET ITEM Fees Accr./Def.' where code='01.09.000005';
update cfe.ledger_account set description='Non-financial assets' where code='01.10.';
update cfe.ledger_account set description='Non-financial assets' where code='01.10.000001';
update cfe.ledger_account set description='Reinsurance liabilities' where code='01.11.';
update cfe.ledger_account set description='Incurred Insurance Assets' where code='02.11.000001';
update cfe.ledger_account set description='Best Estimate Reinsurance' where code='02.11.000002';
update cfe.ledger_account set description='Risk Margin Reinsurance' where code='02.11.000003';
update cfe.ledger_account set description='Residual Margin Reinsurance' where code='02.11.000004';
update cfe.ledger_account set description='Liability' where code='02.';
update cfe.ledger_account set description='Current liabilities' where code='02.01.';
update cfe.ledger_account set description='Current liabilities in cash' where code='02.01.000001';
update cfe.ledger_account set description='Current accounts (CURACC) liabilties' where code='02.02.';
update cfe.ledger_account set description='CURACC L Daily Payable Liabilities' where code='02.02.000001';
update cfe.ledger_account set description='CURACC L Interest Accrual/Deferral Payable' where code='02.02.000002';
update cfe.ledger_account set description='CURACC L Fees Accrual/Deferral' where code='02.02.000005';
update cfe.ledger_account set description='MM and deposits liabilities' where code='02.03.';
update cfe.ledger_account set description='MM L Nominal 02.03.000002 MM L Interest Accrual/Deferral' where code='02.03.000001';
update cfe.ledger_account set description='MM L Premium/Discount' where code='02.03.000003';
update cfe.ledger_account set description='MM L Transaction Cost' where code='02.03.000004';
update cfe.ledger_account set description='MM L Fees Accrual/Deferral' where code='02.03.000005';
update cfe.ledger_account set description='MM L Interest Smoothing Effect' where code='02.03.000006';
update cfe.ledger_account set description='MM L Value Changes Market Price' where code='02.03.000007';
update cfe.ledger_account set description='MM L Value Changes Credit Spread' where code='02.03.000008';
update cfe.ledger_account set description='OWN ISSUE bonds' where code='02.04.';
update cfe.ledger_account set description='OWN ISSUE Nominal' where code='02.04.000001';
update cfe.ledger_account set description='OWN ISSUE Interest Accrual/Deferral' where code='02.04.000002';
update cfe.ledger_account set description='OWN ISSUE Premium/Discount' where code='02.04.000003';
update cfe.ledger_account set description='OWN ISSUE Transaction Costs' where code='02.04.000004';
update cfe.ledger_account set description='OWN ISSUE Fees Accrual/Deferral' where code='02.04.000005';
update cfe.ledger_account set description='OWN ISSUE Interest Smoothing Effect' where code='02.04.000006';
update cfe.ledger_account set description='OWN ISSUE Value Changes Market Price' where code='02.04.000007';
update cfe.ledger_account set description='OWN ISSUE Value Changes Credit Spread' where code='02.04.000008';
update cfe.ledger_account set description='REPO Liabilities' where code='02.05.';
update cfe.ledger_account set description='REPO L Nominal' where code='02.05.000001';
update cfe.ledger_account set description='REPO L Interest Accrual/Deferral' where code='02.05.000002';
update cfe.ledger_account set description='REPO L Premium/Discount' where code='02.05.000003';
update cfe.ledger_account set description='Equity' where code='02.06.';
update cfe.ledger_account set description='Previous year Profit and Loss' where code='02.06.000001';
update cfe.ledger_account set description='AFS revaluation reserve' where code='02.06.000002';
update cfe.ledger_account set description='Equity from non-financial instruments' where code='02.06.000003';
update cfe.ledger_account set description='First Adoption Effect IFRS' where code='02.06.000004';
update cfe.ledger_account set description='Savings (SAV)' where code='02.07.';
update cfe.ledger_account set description='SAV Nominal' where code='02.07.000001';
update cfe.ledger_account set description='SAV Interest Accrual/Deferral' where code='02.07.000002';
update cfe.ledger_account set description='SAV Premium/Discount' where code='02.07.000003';
update cfe.ledger_account set description='SAV Transaction Cost' where code='02.07.000004';
update cfe.ledger_account set description='SAV Fees Accrual/Deferral' where code='02.07.000005';
update cfe.ledger_account set description='SAV Interest Smoothing Effect' where code='02.07.000006';
update cfe.ledger_account set description='BOND SHORT Position' where code='02.08.';
update cfe.ledger_account set description='BOND SHORT Nominal' where code='02.08.000001';
update cfe.ledger_account set description='BOND SHORT Interest Accrual/Deferral' where code='02.08.000002';
update cfe.ledger_account set description='BOND Trading Position' where code='01.04.100003';
update cfe.ledger_account set description='DERIVATIVE liabilities' where code='02.09.';
update cfe.ledger_account set description='DERIVATIVES L Account' where code='02.09.000001';
update cfe.ledger_account set description='DERIVATIVES L Interest Accrual' where code='02.09.000002';
update cfe.ledger_account set description='DERIVATIVES L Valuation' where code='02.09.000007';
update cfe.ledger_account set description='Non-financial liabilities' where code='02.10.';
update cfe.ledger_account set description='Non-financial liabilities' where code='02.10.000001';
update cfe.ledger_account set description='Insurance liabilities' where code='02.11.';
update cfe.ledger_account set description='Incurred Insurance liability' where code='02.11.000001';
update cfe.ledger_account set description='Best Estimate' where code='02.11.000002';
update cfe.ledger_account set description='Risk Margin' where code='02.11.000003';
update cfe.ledger_account set description='Residual Margin' where code='02.11.000004';
update cfe.ledger_account set description='Expense/Income' where code='06.';
update cfe.ledger_account set description='Interest income' where code='06.01.';
update cfe.ledger_account set description='CURACC A Interest Income' where code='06.01.200001';
update cfe.ledger_account set description='CURACC A Fees Accrual/Deferral Income' where code='06.01.200004';
update cfe.ledger_account set description='CURACC L Fees Accrual/Deferral Income' where code='06.01.220004';
update cfe.ledger_account set description='MM A Interest Income' where code='06.01.300001';
update cfe.ledger_account set description='MM A Amortisation Income Discount' where code='06.01.300002';
update cfe.ledger_account set description='MM A Amortisation Transaction Costs Income' where code='06.01.300003';
update cfe.ledger_account set description='MM A Fees Accrual/Deferral Income' where code='06.01.300004';
update cfe.ledger_account set description='MM A Interest Smoothing Effect Income' where code='06.01.300005';
update cfe.ledger_account set description='MM L Amortisation Income Premium' where code='06.01.320002';
update cfe.ledger_account set description='MM L Amortisation Transaction Costs Income' where code='06.01.320003';
update cfe.ledger_account set description='MM L Fees Accrual/Deferral Income' where code='06.01.320004';
update cfe.ledger_account set description='BOND Interest Income' where code='06.01.400001';
update cfe.ledger_account set description='BOND Amortisation Income Discount' where code='06.01.400002';
update cfe.ledger_account set description='BOND Amortisation Income Transaction Cost' where code='06.01.400003';
update cfe.ledger_account set description='BOND Fees Accrual/Deferral Income' where code='06.01.400004';
update cfe.ledger_account set description='BOND Interest Smoothing Effect' where code='06.01.400005';
update cfe.ledger_account set description='OWN ISSUE Amortisation Income Premium' where code='06.01.420002';
update cfe.ledger_account set description='OWN ISSUE Amortisation Income Transaction Costs' where code='06.01.420003';
update cfe.ledger_account set description='OWN ISSUE Fees Accrual/Deferral Income' where code='06.01.420004';
update cfe.ledger_account set description='REPO A Interest Income' where code='06.01.500001';
update cfe.ledger_account set description='REPO A Amortisation Income' where code='06.01.500002';
update cfe.ledger_account set description='LN Interest Income' where code='06.01.700001';
update cfe.ledger_account set description='LN Amortisation Income Discount' where code='06.01.700002';
update cfe.ledger_account set description='LN Amortisation Income Transaction Costs' where code='06.01.700003';
update cfe.ledger_account set description='LN Fees Accrual/Deferral Income' where code='06.01.700004';
update cfe.ledger_account set description='LN Interest Smoothing Effect' where code='06.01.700005';
update cfe.ledger_account set description='LN Amortisation Income BMR Discount' where code='06.01.700006';
update cfe.ledger_account set description='LN Unwinding' where code='06.01.700007';
update cfe.ledger_account set description='LN Penalty Interest Income' where code='06.01.700013';
update cfe.ledger_account set description='SAV Amortisation Income Premium' where code='06.01.720002';
update cfe.ledger_account set description='SAV Amortisation Income Transaction Costs' where code='06.01.720003';
update cfe.ledger_account set description='SAV Fees Accrual/Deferral Income' where code='06.01.720004';
update cfe.ledger_account set description='DERIVATIVES Interest Income' where code='06.01.800001';
update cfe.ledger_account set description='DERIVATIVES Fees Accual/Deferral Income' where code='06.01.800004';
update cfe.ledger_account set description='OFF-BALANCE SHEET ITEM Fees Accrual/Deferral Income' where code='06.01.900004';
update cfe.ledger_account set description='Income from one-time fees' where code='06.02.';
update cfe.ledger_account set description='CURACC Fees Income' where code='06.02.200001';
update cfe.ledger_account set description='MM A Fees Income' where code='06.02.300001';
update cfe.ledger_account set description='MM L Fees Income' where code='06.02.320001';
update cfe.ledger_account set description='BOND Fees Incomes' where code='06.02.400001';
update cfe.ledger_account set description='OWN ISSUE Fees Income' where code='06.02.420001';
update cfe.ledger_account set description='LN Fees Income' where code='06.02.700001';
update cfe.ledger_account set description='DERIVATIVES Fees Income' where code='06.02.800002';
update cfe.ledger_account set description='BOND SHORT Fees Income' where code='06.02.820001';
update cfe.ledger_account set description='OFF-BALANCE SHEET ITEM Fees Income' where code='06.02.900001';
update cfe.ledger_account set description='Interest expense' where code='06.03.';
update cfe.ledger_account set description='CURACC L Interest Expense' where code='06.03.200001';
update cfe.ledger_account set description='CURACC L Fees Accrual/Deferral Expense' where code='06.03.200004';
update cfe.ledger_account set description='CURACC A Fees Accrual/Deferral Expense' where code='06.03.220004';
update cfe.ledger_account set description='MM L Interest Expense' where code='06.03.300001';
update cfe.ledger_account set description='MM L Amortisation Expense Discount' where code='06.03.300002';
update cfe.ledger_account set description='MM L Amortisation Expense Transaction Costs' where code='06.03.300003';
update cfe.ledger_account set description='MM L Fees Accrual/Deferral Expense' where code='06.03.300004';
update cfe.ledger_account set description='MM L Interest Smoothing Effect Expense' where code='06.03.300005';
update cfe.ledger_account set description='MM A Amortisation Expense Premium' where code='06.03.320002';
update cfe.ledger_account set description='MM A Amortisation Expense Transaction Costs' where code='06.03.320003';
update cfe.ledger_account set description='MM A Fees Accrual/Deferral Expense' where code='06.03.320004';
update cfe.ledger_account set description='OWN ISSUE Interest Expense' where code='06.03.400001';
update cfe.ledger_account set description='OWN ISSUE Amortisation Expense Discount' where code='06.03.400002';
update cfe.ledger_account set description='OWN ISSUE Amortisation Expense Transaction Cost' where code='06.03.400003';
update cfe.ledger_account set description='OWN ISSUE Fees Accrual/Deferral Expense' where code='06.03.400004';
update cfe.ledger_account set description='OWN ISSUE Interest Smoothing Effect Expense' where code='06.03.400005';
update cfe.ledger_account set description='BOND Amortisation Expense Premium' where code='06.03.420002';
update cfe.ledger_account set description='BOND Amortisation Expense Transaction Costs' where code='06.03.420003';
update cfe.ledger_account set description='BOND Fees Accrual/Deferral Expense' where code='06.03.420004';
update cfe.ledger_account set description='REPO L Interest Expense' where code='06.03.500001';
update cfe.ledger_account set description='REPO L Amortisation Expense' where code='06.03.500002';
update cfe.ledger_account set description='SAV Interest Expense' where code='06.03.700001';
update cfe.ledger_account set description='SAV Amortisation Expense Discount' where code='06.03.700002';
update cfe.ledger_account set description='SAV Amortisation Expense Transaction Costs' where code='06.03.700003';
update cfe.ledger_account set description='SAV Fees Accrual/Deferral Expense' where code='06.03.700004';
update cfe.ledger_account set description='SAV Interest Smoothing Effect Expense' where code='06.03.700005';
update cfe.ledger_account set description='LN Amortisation Expense Premium' where code='06.03.720002';
update cfe.ledger_account set description='LN Amortisation Expense Transaction Costs' where code='06.03.720003';
update cfe.ledger_account set description='LN Fees Accrual/Deferral Expense' where code='06.03.720004';
update cfe.ledger_account set description='DERIVATIVES Interest Expense' where code='06.03.800001';
update cfe.ledger_account set description='DERIVATIVES Fees Accual/Deferral Expense' where code='06.03.800004';
update cfe.ledger_account set description='OFF-BALANCE SHEET ITEM Fees Accrual/Deferral Expense' where code='06.03.900004';
update cfe.ledger_account set description='Expense from one-time fees' where code='06.04.';
update cfe.ledger_account set description='CURACC Fees Expense' where code='06.04.200001';
update cfe.ledger_account set description='MM A Fees Expense' where code='06.04.300001';
update cfe.ledger_account set description='MM L Fees Expense' where code='06.04.320001';
update cfe.ledger_account set description='BOND Fees Expense' where code='06.04.400001';
update cfe.ledger_account set description='OWN ISSUE Fees Expense' where code='06.04.420001';
update cfe.ledger_account set description='LN Fees Expense' where code='06.04.700001';
update cfe.ledger_account set description='LN BMR Discount Expense' where code='06.04.700009';
update cfe.ledger_account set description='DERIVATIVES Fees Expense' where code='06.04.800002';
update cfe.ledger_account set description='BOND SHORT Fees Expense' where code='06.04.820001';
update cfe.ledger_account set description='OFF-BALANCE SHEET ITEM Fees Expense' where code='06.04.900001';
update cfe.ledger_account set description='Impairment expense' where code='06.05.';
update cfe.ledger_account set description='LN Impairment Expense' where code='06.05.000001';
update cfe.ledger_account set description='PORTFOLIO Impairment Expense' where code='06.05.000003';
update cfe.ledger_account set description='CURACC Impairment Expense' where code='06.05.000005';
update cfe.ledger_account set description='Trade and Valuation result HFT / AFV' where code='06.06.';
update cfe.ledger_account set description='MM A Valuation Result' where code='06.06.300001';
update cfe.ledger_account set description='MM A Trade Result' where code='06.06.300002';
update cfe.ledger_account set description='MM L Valuation Result' where code='06.06.320001';
update cfe.ledger_account set description='MM L Trade Result' where code='06.06.320002';
update cfe.ledger_account set description='BOND Valuation Result' where code='06.06.400001';
update cfe.ledger_account set description='BOND Trade Result' where code='06.06.400002';
update cfe.ledger_account set description='OWN ISSUE Valuation Result' where code='06.06.420001';
update cfe.ledger_account set description='OWN ISSUE Trade Result' where code='06.06.420002';
update cfe.ledger_account set description='LN Valuation Result' where code='06.06.700001';
update cfe.ledger_account set description='LN Trade Result' where code='06.06.700002';
update cfe.ledger_account set description='DERIVATIVES Valuation Result' where code='06.06.800001';
update cfe.ledger_account set description='Other Income / Expense' where code='06.07.';
update cfe.ledger_account set description='Foreign Exchange Valuation Foreign Exchange Valuation' where code='06.07.999999';
update cfe.ledger_account set description='Income from non-financial instruments' where code='06.08';
update cfe.ledger_account set description='Income from non-financial instruments' where code='06.08.000001';
update cfe.ledger_account set description='Expense from non-financial instruments' where code='06.09';
update cfe.ledger_account set description='Expense from non-financial assets' where code='06.09.000001';
update cfe.ledger_account set description='Insurance Income/Expense' where code='06.11.';
update cfe.ledger_account set description='Premium Income Insurance' where code='06.11.000001';
update cfe.ledger_account set description='Premium Expense Re-Insurance' where code='06.11.000002';
update cfe.ledger_account set description='Claim Expense Insurance' where code='06.11.100001';
update cfe.ledger_account set description='Claim Income Re-Insurance' where code='06.01.100002';
update cfe.ledger_account set description='Off-Balance-Asset-Liabilities' where code='09.';
update cfe.ledger_account set description='Off-balance assets' where code='09.01.';
update cfe.ledger_account set description='OFF-BALANCE SHEET ITEM Asset Account' where code='09.01.900001';
update cfe.ledger_account set description='DERIVATIVES A Account Off-Balance' where code='09.01.800001';
update cfe.ledger_account set description='OFF-BALANCE SHEET ITEM Settlement Account Off-Bal' where code='09.0x.999999';
update cfe.ledger_account set description='Non-financial off-balance assets' where code='09.01.000001';
update cfe.ledger_account set description='Off-balance liabilitites' where code='09.02.';
update cfe.ledger_account set description='OFF-BALANCE SHEET ITEM Liability Account' where code='09.02.900001';
update cfe.ledger_account set description='DERIVATIVES L Account Off-Balance' where code='09.02.800001';
update cfe.ledger_account set description='Non-financial off-balance liabilities' where code='09.02.000001';
